HttpClientException class

Thrown when the underlying libcurl call fails before we have a server status (DNS, TLS, connect, cancel, etc.) or when the caller has not configured the adapter yet.

Implemented types

Constructors

HttpClientException(String message, {int statusCode = 0})

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited