HttpClientResponse class

Minimal response container, platform-agnostic.

Constructors

HttpClientResponse({required int statusCode, required Map<String, String> headers, required Uint8List bodyBytes, int elapsedMs = 0})

Properties

body String
Lazily-decoded UTF-8 body. Safe on binary payloads (returns replacement chars), but callers that need bytes should use bodyBytes directly.
no setter
bodyBytes Uint8List
final
elapsedMs int
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
isSuccess bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited