RacHttpDownloadRequest class base

Matches rac_http_download_request_t.

Inheritance
Implemented types
Available extensions

Constructors

RacHttpDownloadRequest()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
destinationPath Pointer<Utf8>
getter/setter pair
expectedSha256Hex Pointer<Utf8>
getter/setter pair
followRedirects int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
headerCount int
getter/setter pair
headers Pointer<RacHttpHeaderKv>
getter/setter pair
resumeFromByte int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeoutMs int
getter/setter pair
url Pointer<Utf8>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited