DartBridgeStructuredOutput class

Structured output FFI bridge for C++ interop.

Provides access to C++ structured output functions:

  • rac_structured_output_get_system_prompt
  • rac_structured_output_extract_json
  • rac_structured_output_prepare_prompt
  • rac_structured_output_validate

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

extractJson(String text) String?
Extract JSON from generated text Uses C++ rac_structured_output_extract_json
getSystemPrompt(String schema) String
Get system prompt for structured output generation Uses C++ rac_structured_output_get_system_prompt
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preparePrompt(String originalPrompt, String schema, {bool includeSchemaInPrompt = true}) String
Prepare prompt with structured output instructions Uses C++ rac_structured_output_prepare_prompt
toString() String
A string representation of this object.
inherited
validate(String text, String schema) StructuredOutputValidationResult
Validate structured output Uses C++ rac_structured_output_validate

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

shared DartBridgeStructuredOutput
final