ToolCallParseResult class

Tool call parse result from C++

Constructors

ToolCallParseResult({required bool hasToolCall, required String cleanText, String? toolName, Map<String, dynamic>? arguments, required int callId})

Properties

arguments Map<String, dynamic>?
final
callId int
final
cleanText String
final
hashCode int
The hash code for this object.
no setterinherited
hasToolCall bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolName String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited