TTSComponentResult class
Result from TTS synthesis.
Constructors
- TTSComponentResult({required Float32List samples, required int sampleRate, required int durationMs})
-
const
Properties
- durationMs → int
-
final
- durationSeconds → double
-
Duration in seconds.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleRate → int
-
final
- samples → Float32List
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited