VADSpeechStartedEvent class

Speech started event.

Inheritance

Constructors

VADSpeechStartedEvent({required double energy, required double probability})
const

Properties

energy double
final
hashCode int
The hash code for this object.
no setterinherited
probability double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited