DevModeConfig class
Development (Supabase) Configuration
Matches React Native DevModeConfig interface.
Constructors
- DevModeConfig({required String supabaseURL, required String supabaseKey})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supabaseKey → String
-
Supabase anon key
final
- supabaseURL → String
-
Supabase project URL
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited