NetworkConfig class

Network configuration options for SDK initialization

Matches React Native NetworkConfig interface.

Constructors

NetworkConfig({String? baseURL, required String apiKey, SDKEnvironment environment = SDKEnvironment.production, SupabaseNetworkConfig? supabase, int timeoutMs = defaultTimeoutMs})
const

Properties

apiKey String
API key for authentication
final
baseURL String?
Base URL for API requests
final
environment SDKEnvironment
SDK environment
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supabase SupabaseNetworkConfig?
Supabase configuration for development mode When provided in development mode, SDK makes calls directly to Supabase
final
timeoutMs int
Request timeout in milliseconds
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultBaseURL → const String
Default production base URL
defaultTimeoutMs → const int
Default timeout in milliseconds