TelemetryCategory enum

Telemetry event categories (matches C++/Swift/React Native categories)

Inheritance
Available extensions

Values

sdk → const TelemetryCategory
model → const TelemetryCategory
llm → const TelemetryCategory
stt → const TelemetryCategory
tts → const TelemetryCategory
vad → const TelemetryCategory
voiceAgent → const TelemetryCategory
error → const TelemetryCategory

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String

Available on TelemetryCategory, provided by the TelemetryCategoryExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TelemetryCategory>
A constant List of the values in this enum, in order of their declaration.