TelemetryEvent class

Telemetry event model

Constructors

TelemetryEvent({String? id, required String type, required TelemetryCategory category, Map<String, dynamic>? properties, DateTime? timestamp})

Properties

category TelemetryCategory
final
createdAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
properties Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toProductionJson() Map<String, dynamic>
Convert to JSON for Production (Railway) Matches C++ telemetry_json.cpp rac_telemetry_manager_payload_to_json()
toString() String
A string representation of this object.
inherited
toSupabaseJson({required String deviceId, required String sdkVersion, required String platform}) Map<String, dynamic>
Convert to JSON for Supabase (development) Uses column names expected by Supabase telemetry_events table Schema matches C++ telemetry_json.cpp rac_telemetry_manager_payload_to_json()

Operators

operator ==(Object other) bool
The equality operator.
inherited