SecureStorageKeys class

SecureStorageKeys

Keychain/secure storage key constants

Reference: sdk/runanywhere-swift/Sources/RunAnywhere/Foundation/Security/KeychainManager.swift Reference: sdk/runanywhere-react-native/packages/core/src/Foundation/Security/SecureStorageKeys.ts

These keys are used for:

  • iOS: Keychain (survives app reinstalls)
  • Android: EncryptedSharedPreferences (survives app reinstalls)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

accessToken → const String
apiKey → const String
baseURL → const String
deviceId → const String
deviceRegistered → const String
deviceUUID → const String
environment → const String
organizationId → const String
refreshToken → const String
tokenExpiresAt → const String
userId → const String