MessageRole class


Conversational role of a ChatMessage.

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) MessageRole?

Constants

MESSAGE_ROLE_ASSISTANT → const MessageRole
MESSAGE_ROLE_DEVELOPER → const MessageRole
MESSAGE_ROLE_SYSTEM → const MessageRole
MESSAGE_ROLE_TOOL → const MessageRole
Tool-result messages injected back into the conversation after a tool call has been executed. Required for OpenAI-style tool flows.
MESSAGE_ROLE_UNSPECIFIED → const MessageRole
MESSAGE_ROLE_USER → const MessageRole
values → const List<MessageRole>