FormFactor class
Physical device class.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → FormFactor?
Constants
- FORM_FACTOR_DESKTOP → const FormFactor
- FORM_FACTOR_HEADSET → const FormFactor
- FORM_FACTOR_LAPTOP → const FormFactor
- FORM_FACTOR_PHONE → const FormFactor
- FORM_FACTOR_TABLET → const FormFactor
- FORM_FACTOR_TV → const FormFactor
- FORM_FACTOR_UNSPECIFIED → const FormFactor
- FORM_FACTOR_WATCH → const FormFactor
-
values
→ const List<
FormFactor>