DiffusionMode class
Generation mode. Sources pre-IDL (identical across all surfaces):
Swift DiffusionTypes.swift:257 (textToImage / imageToImage / inpainting)
Kotlin DiffusionTypes.kt:188 (TEXT_TO_IMAGE / IMAGE_TO_IMAGE / INPAINTING)
RN DiffusionTypes.ts:73 (TextToImage / ImageToImage / Inpainting)
Web DiffusionTypes.ts:23 (TextToImage / ImageToImage / Inpainting)
C ABI rac_diffusion_types.h:59 (RAC_DIFFUSION_MODE_*)
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
name
→ String
-
This enum's name, as specified in the .proto file.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
→ int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
Returns this enum's
name or the value if names are not represented.
inherited