DiffusionModelVariant class


Stable Diffusion model variant. Sources pre-IDL (identical 6 cases): Swift DiffusionTypes.swift:92 (sd15 / sd21 / sdxl / sdxlTurbo / sdxs / lcm) Kotlin DiffusionTypes.kt:85 (SD15 / SD21 / SDXL / SDXL_TURBO / SDXS / LCM) RN DiffusionTypes.ts:28 (SD15 / SD21 / SDXL / SDXLTurbo / SDXS / LCM) Web DiffusionTypes.ts:14 (numeric SD_1_5 / SD_2_1 / SDXL / SDXL_Turbo / SDXS / LCM) C ABI rac_diffusion_types.h:47 (RAC_DIFFUSION_MODEL_*)

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) DiffusionModelVariant?