HardwareApi class

Constructors

HardwareApi(RpcClient _client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAccelerators(ClientContext? ctx, HardwareAcceleratorsRequest request) Future<HardwareProfileResult>
getProfile(ClientContext? ctx, HardwareProfileRequest request) Future<HardwareProfileResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
probeNpu(ClientContext? ctx, NpuProbeRequest request) Future<NpuCapability>
Pre-flight Hexagon NPU capability (rac_qhexrt_probe_proto).
setAcceleratorPreference(ClientContext? ctx, HardwareAcceleratorPreferenceRequest request) Future<HardwareAcceleratorPreferenceResult>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited