stopSequences property
Stop sequences. Generation halts when any of these strings appears in the output stream.
Implementation
@$pb.TagNumber(6)
$pb.PbList<$core.String> get stopSequences => $_getList(5);
Stop sequences. Generation halts when any of these strings appears in the output stream.
@$pb.TagNumber(6)
$pb.PbList<$core.String> get stopSequences => $_getList(5);