toolCalls property
Tool calls parsed from the final assistant response, if any.
Implementation
@$pb.TagNumber(23)
$pb.PbList<$2.ToolCall> get toolCalls => $_getList(22);
Tool calls parsed from the final assistant response, if any.
@$pb.TagNumber(23)
$pb.PbList<$2.ToolCall> get toolCalls => $_getList(22);