reasons property
Human-readable reasons populated when the verdict is negative (e.g. "insufficient RAM: requires X, available Y").
Implementation
@$pb.TagNumber(8)
$pb.PbList<$core.String> get reasons => $_getList(7);
Human-readable reasons populated when the verdict is negative (e.g. "insufficient RAM: requires X, available Y").
@$pb.TagNumber(8)
$pb.PbList<$core.String> get reasons => $_getList(7);