ModelLoadResult class

Available extensions

Constructors

ModelLoadResult({bool? success, String? modelId, ModelCategory? category, InferenceFramework? framework, String? resolvedPath, Int64? loadedAtUnixMs, String? errorMessage, Iterable<String>? warnings, bool? alreadyLoaded, Iterable<ModelFileDescriptor>? resolvedArtifacts})
factory
ModelLoadResult.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
ModelLoadResult.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

alreadyLoaded bool
getter/setter pair
category ModelCategory
getter/setter pair
errorMessage String
getter/setter pair
framework InferenceFramework
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
lifecyclePrimaryArtifactPath String?

Available on ModelLoadResult, provided by the ModelLoadResultResolvedArtifacts extension

no setter
loadedAtUnixMs ↔ Int64
getter/setter pair
modelId String
getter/setter pair
resolvedArtifacts → PbList<ModelFileDescriptor>
Concrete artifacts selected by C++ model path resolution. The primary model entry mirrors resolved_path; companion entries carry explicit ModelFileRole values such as MODEL_FILE_ROLE_VISION_PROJECTOR.
no setter
resolvedConfigPath String?

Available on ModelLoadResult, provided by the ModelLoadResultResolvedArtifacts extension

no setter
resolvedLabelsPath String?

Available on ModelLoadResult, provided by the ModelLoadResultResolvedArtifacts extension

no setter
resolvedMergesPath String?

Available on ModelLoadResult, provided by the ModelLoadResultResolvedArtifacts extension

no setter
resolvedPath String
getter/setter pair
resolvedPrimaryModelPath String?

Available on ModelLoadResult, provided by the ModelLoadResultResolvedArtifacts extension

no setter
resolvedTokenizerPath String?

Available on ModelLoadResult, provided by the ModelLoadResultResolvedArtifacts extension

no setter
resolvedVisionProjectorPath String?

Available on ModelLoadResult, provided by the ModelLoadResultResolvedArtifacts extension

no setter
resolvedVocabularyPath String?

Available on ModelLoadResult, provided by the ModelLoadResultResolvedArtifacts extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
warnings → PbList<String>
no setter

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAlreadyLoaded() → void
clearCategory() → void
clearErrorMessage() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFramework() → void
clearLoadedAtUnixMs() → void
clearModelId() → void
clearResolvedPath() → void
clearSuccess() → void
clone() ModelLoadResult
Creates a deep copy of the fields in this message.
copyWith(void updates(ModelLoadResult)) ModelLoadResult
Apply updates to a copy of this message.
createEmptyInstance() ModelLoadResult
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasAlreadyLoaded() bool
hasCategory() bool
hasErrorMessage() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasFramework() bool
hasLoadedAtUnixMs() bool
hasModelId() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasResolvedPath() bool
hasSuccess() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
requireResolvedArtifactPaths() ModelLifecycleResolvedArtifactPaths

Available on ModelLoadResult, provided by the ModelLoadResultResolvedArtifacts extension

resolvedModelFilePath(ModelFileRole role) String?

Available on ModelLoadResult, provided by the ModelLoadResultResolvedArtifacts extension

setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() ModelLoadResult
getDefault() ModelLoadResult