ArchiveType class

Compression flavor of a multi-file model package.

Available extensions

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toC() int

Available on ArchiveType, provided by the ProtoArchiveTypeCppBridge extension

Convert a generated archive type enum to C++ rac_archive_type_t. Delegates to commons' rac_archive_type_from_proto. Returns RAC_ARCHIVE_TYPE_NONE (-1) on UNSPECIFIED / unrecognized inputs.
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) ArchiveType?