ModelFileRole class
Role of a file inside a single/multi-file artifact. The generic COMPANION role covers arbitrary sidecars; specific roles document common public catalog files such as VLM mmproj files and tokenizer/config assets.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → ModelFileRole?
Constants
- MODEL_FILE_ROLE_COMPANION → const ModelFileRole
- MODEL_FILE_ROLE_CONFIG → const ModelFileRole
- MODEL_FILE_ROLE_LABELS → const ModelFileRole
- MODEL_FILE_ROLE_MERGES → const ModelFileRole
- MODEL_FILE_ROLE_PRIMARY_MODEL → const ModelFileRole
- MODEL_FILE_ROLE_TOKENIZER → const ModelFileRole
- MODEL_FILE_ROLE_UNSPECIFIED → const ModelFileRole
- MODEL_FILE_ROLE_VISION_PROJECTOR → const ModelFileRole
- MODEL_FILE_ROLE_VOCABULARY → const ModelFileRole
-
values
→ const List<
ModelFileRole>