ModelFormat class
Model file format — union across all SDKs. Sources pre-IDL: Swift ModelTypes.swift:27 (onnx, ort, gguf, bin, coreml, unknown) Kotlin ModelTypes.kt:41 (ONNX, ORT, GGUF, BIN, QNN_CONTEXT, UNKNOWN) Dart model_types.dart:34 (onnx, ort, gguf, bin, unknown) RN enums.ts:115 (12-case superset incl. MLModel, MLPackage, TFLite, SafeTensors, Zip, Folder, Proprietary) Web enums.ts:56 (copy of RN)
- Available extensions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- rawValue → String
-
Available on ModelFormat, provided by the ProtoModelFormatCppBridge extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toC(
) → int -
Available on ModelFormat, provided by the ProtoModelFormatCppBridge extension
Convert a generated model format enum to C++ rac_model_format_t. Delegates to commons'rac_model_format_from_proto. -
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → ModelFormat?
Constants
- MODEL_FORMAT_BIN → const ModelFormat
- MODEL_FORMAT_COREML → const ModelFormat
- MODEL_FORMAT_FOLDER → const ModelFormat
- MODEL_FORMAT_GGML → const ModelFormat
- MODEL_FORMAT_GGUF → const ModelFormat
- MODEL_FORMAT_MLMODEL → const ModelFormat
- MODEL_FORMAT_MLPACKAGE → const ModelFormat
- MODEL_FORMAT_ONNX → const ModelFormat
- MODEL_FORMAT_ORT → const ModelFormat
- MODEL_FORMAT_PROPRIETARY → const ModelFormat
- MODEL_FORMAT_QNN_CONTEXT → const ModelFormat
- MODEL_FORMAT_SAFETENSORS → const ModelFormat
- MODEL_FORMAT_TFLITE → const ModelFormat
- MODEL_FORMAT_UNKNOWN → const ModelFormat
- MODEL_FORMAT_UNSPECIFIED → const ModelFormat
- MODEL_FORMAT_ZIP → const ModelFormat
-
values
→ const List<
ModelFormat>