ModelSource class
Model source — where the catalog entry came from.
- Available extensions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
- wireString → String
-
Available on ModelSource, provided by the ModelSourceWireString extension
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toC(
) → int -
Available on ModelSource, provided by the ProtoModelSourceCppBridge extension
Convert a generated model source enum to C++ rac_model_source_t. Delegates to commons'rac_model_source_from_proto. -
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → ModelSource?
Constants
- MODEL_SOURCE_BUILT_IN → const ModelSource
- MODEL_SOURCE_LOCAL → const ModelSource
- MODEL_SOURCE_REMOTE → const ModelSource
- MODEL_SOURCE_UNSPECIFIED → const ModelSource
-
values
→ const List<
ModelSource>