RoutingPolicy class
Routing policy for hybrid (on-device vs cloud) inference. Sources pre-IDL: Web enums.ts (RoutingPolicy) OnDevicePreferred / CloudPreferred / OnDeviceOnly / CloudOnly / Hybrid / CostOptimized / LatencyOptimized / PrivacyOptimized Swift extensions (RoutingPolicy) Canonical short-form below; specific PreferLocal/PreferCloud cover the "preferred" cases, MANUAL covers explicit user override.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → RoutingPolicy?
Constants
- ROUTING_POLICY_COST_OPTIMIZED → const RoutingPolicy
- ROUTING_POLICY_LATENCY_OPTIMIZED → const RoutingPolicy
- ROUTING_POLICY_MANUAL → const RoutingPolicy
- ROUTING_POLICY_PREFER_CLOUD → const RoutingPolicy
- ROUTING_POLICY_PREFER_LOCAL → const RoutingPolicy
- ROUTING_POLICY_UNSPECIFIED → const RoutingPolicy
-
values
→ const List<
RoutingPolicy>