DeviceAffinity class

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) DeviceAffinity?

Constants

DEVICE_AFFINITY_ANY → const DeviceAffinity
DEVICE_AFFINITY_CPU → const DeviceAffinity
DEVICE_AFFINITY_GPU → const DeviceAffinity
DEVICE_AFFINITY_NPU → const DeviceAffinity
Vendor-neutral neural accelerator: Apple Neural Engine, Qualcomm Hexagon NPU, etc. The YAML loader already accepts "npu" for this value.
DEVICE_AFFINITY_UNSPECIFIED → const DeviceAffinity
values → const List<DeviceAffinity>