EdgePolicy class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → EdgePolicy?
Constants
- EDGE_POLICY_BLOCK → const EdgePolicy
- Producer blocks when channel is full (default, safest).
- EDGE_POLICY_DROP_NEWEST → const EdgePolicy
- Newest item is dropped when channel is full (pager coalescing).
- EDGE_POLICY_DROP_OLDEST → const EdgePolicy
- Oldest item is dropped when channel is full (audio routing only).
- EDGE_POLICY_UNSPECIFIED → const EdgePolicy
-
values
→ const List<
EdgePolicy>