Rac_options class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
racAnalyticsKey
→ Extension<
String> -
final
-
racDefault
→ Extension<
String> -
final
-
racDisplayName
→ Extension<
String> -
final
-
racMax
→ Extension<
int> -
final
-
racMaxFloat
→ Extension<
double> -
final
-
racMin
→ Extension<
int> -
final
-
racMinFloat
→ Extension<
double> -
final
-
racRequired
→ Extension<
bool> -
final
-
racWireString
→ Extension<
String> -
final
Static Methods
-
registerAllExtensions(
ExtensionRegistry registry) → void