RAGStreamEventKind class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → RAGStreamEventKind?
Constants
- RAG_STREAM_EVENT_KIND_CHUNK_RETRIEVED → const RAGStreamEventKind
- RAG_STREAM_EVENT_KIND_COMPLETED → const RAGStreamEventKind
- RAG_STREAM_EVENT_KIND_CONTEXT_READY → const RAGStreamEventKind
- RAG_STREAM_EVENT_KIND_ERROR → const RAGStreamEventKind
- RAG_STREAM_EVENT_KIND_RETRIEVAL_STARTED → const RAGStreamEventKind
- RAG_STREAM_EVENT_KIND_TOKEN → const RAGStreamEventKind
- RAG_STREAM_EVENT_KIND_UNSPECIFIED → const RAGStreamEventKind
-
values
→ const List<
RAGStreamEventKind>