normalizeEnvelope property

  1. @TagNumber.new(2)
bool get normalizeEnvelope

When true, the portable event layer fills missing envelope metadata such as id, timestamp, destination, category/component defaults, source, and correlation fields before routing the event.

Implementation

@$pb.TagNumber(2)
$core.bool get normalizeEnvelope => $_getBF(1);
  1. @TagNumber.new(2)
set normalizeEnvelope (bool value)

Implementation

@$pb.TagNumber(2)
set normalizeEnvelope($core.bool value) => $_setBool(1, value);