replayQueuedEvents property

  1. @TagNumber.new(2)
bool get replayQueuedEvents

Replays queued events before following live events when the backing bridge has a poll queue. Implementations without retention may ignore it and continue with live events only.

Implementation

@$pb.TagNumber(2)
$core.bool get replayQueuedEvents => $_getBF(1);
  1. @TagNumber.new(2)
set replayQueuedEvents (bool value)

Implementation

@$pb.TagNumber(2)
set replayQueuedEvents($core.bool value) => $_setBool(1, value);