AuthEventKind class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → AuthEventKind?
Constants
- AUTH_EVENT_KIND_DEVICE_REGISTERED → const AuthEventKind
- AUTH_EVENT_KIND_DEVICE_REGISTRATION_FAILED → const AuthEventKind
- AUTH_EVENT_KIND_FAILED → const AuthEventKind
- AUTH_EVENT_KIND_REQUESTED → const AuthEventKind
- AUTH_EVENT_KIND_SUCCEEDED → const AuthEventKind
- AUTH_EVENT_KIND_TOKEN_EXPIRED → const AuthEventKind
- AUTH_EVENT_KIND_TOKEN_REFRESHED → const AuthEventKind
- AUTH_EVENT_KIND_UNSPECIFIED → const AuthEventKind
-
values
→ const List<
AuthEventKind>