CapabilityOperationEventKind class

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) CapabilityOperationEventKind?

Constants

CAPABILITY_OPERATION_EVENT_KIND_DIFFUSION_COMPLETED → const CapabilityOperationEventKind
CAPABILITY_OPERATION_EVENT_KIND_DIFFUSION_FAILED → const CapabilityOperationEventKind
CAPABILITY_OPERATION_EVENT_KIND_DIFFUSION_PROGRESS → const CapabilityOperationEventKind
CAPABILITY_OPERATION_EVENT_KIND_DIFFUSION_STARTED → const CapabilityOperationEventKind
CAPABILITY_OPERATION_EVENT_KIND_EMBEDDINGS_COMPLETED → const CapabilityOperationEventKind
CAPABILITY_OPERATION_EVENT_KIND_EMBEDDINGS_FAILED → const CapabilityOperationEventKind
CAPABILITY_OPERATION_EVENT_KIND_EMBEDDINGS_STARTED → const CapabilityOperationEventKind
CAPABILITY_OPERATION_EVENT_KIND_LORA_ATTACHED → const CapabilityOperationEventKind
CAPABILITY_OPERATION_EVENT_KIND_LORA_DETACHED → const CapabilityOperationEventKind
CAPABILITY_OPERATION_EVENT_KIND_LORA_FAILED → const CapabilityOperationEventKind
CAPABILITY_OPERATION_EVENT_KIND_RAG_FAILED → const CapabilityOperationEventKind
CAPABILITY_OPERATION_EVENT_KIND_RAG_INGESTION_COMPLETED → const CapabilityOperationEventKind
CAPABILITY_OPERATION_EVENT_KIND_RAG_INGESTION_STARTED → const CapabilityOperationEventKind
CAPABILITY_OPERATION_EVENT_KIND_RAG_QUERY_COMPLETED → const CapabilityOperationEventKind
CAPABILITY_OPERATION_EVENT_KIND_RAG_QUERY_STARTED → const CapabilityOperationEventKind
CAPABILITY_OPERATION_EVENT_KIND_UNSPECIFIED → const CapabilityOperationEventKind
CAPABILITY_OPERATION_EVENT_KIND_VLM_COMPLETED → const CapabilityOperationEventKind
CAPABILITY_OPERATION_EVENT_KIND_VLM_FAILED → const CapabilityOperationEventKind
CAPABILITY_OPERATION_EVENT_KIND_VLM_STARTED → const CapabilityOperationEventKind
values → const List<CapabilityOperationEventKind>