ComponentInitializationEventKind class

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) ComponentInitializationEventKind?

Constants

COMPONENT_INIT_EVENT_KIND_ALL_COMPONENTS_READY → const ComponentInitializationEventKind
COMPONENT_INIT_EVENT_KIND_COMPONENT_CHECKING → const ComponentInitializationEventKind
COMPONENT_INIT_EVENT_KIND_COMPONENT_DOWNLOAD_COMPLETED → const ComponentInitializationEventKind
COMPONENT_INIT_EVENT_KIND_COMPONENT_DOWNLOAD_PROGRESS → const ComponentInitializationEventKind
COMPONENT_INIT_EVENT_KIND_COMPONENT_DOWNLOAD_REQUIRED → const ComponentInitializationEventKind
COMPONENT_INIT_EVENT_KIND_COMPONENT_DOWNLOAD_STARTED → const ComponentInitializationEventKind
COMPONENT_INIT_EVENT_KIND_COMPONENT_FAILED → const ComponentInitializationEventKind
COMPONENT_INIT_EVENT_KIND_COMPONENT_INITIALIZING → const ComponentInitializationEventKind
COMPONENT_INIT_EVENT_KIND_COMPONENT_READY → const ComponentInitializationEventKind
COMPONENT_INIT_EVENT_KIND_COMPONENT_STATE_CHANGED → const ComponentInitializationEventKind
COMPONENT_INIT_EVENT_KIND_INITIALIZATION_COMPLETED → const ComponentInitializationEventKind
COMPONENT_INIT_EVENT_KIND_INITIALIZATION_STARTED → const ComponentInitializationEventKind
COMPONENT_INIT_EVENT_KIND_PARALLEL_INIT_STARTED → const ComponentInitializationEventKind
COMPONENT_INIT_EVENT_KIND_SEQUENTIAL_INIT_STARTED → const ComponentInitializationEventKind
COMPONENT_INIT_EVENT_KIND_SOME_COMPONENTS_READY → const ComponentInitializationEventKind
COMPONENT_INIT_EVENT_KIND_UNSPECIFIED → const ComponentInitializationEventKind
values → const List<ComponentInitializationEventKind>