ComponentLifecycleEventKind class

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) ComponentLifecycleEventKind?

Constants

COMPONENT_LIFECYCLE_EVENT_KIND_ALL_COMPONENTS_READY → const ComponentLifecycleEventKind
COMPONENT_LIFECYCLE_EVENT_KIND_COMPONENT_CHECKING → const ComponentLifecycleEventKind
COMPONENT_LIFECYCLE_EVENT_KIND_COMPONENT_DOWNLOAD_REQUIRED → const ComponentLifecycleEventKind
COMPONENT_LIFECYCLE_EVENT_KIND_COMPONENT_FAILED → const ComponentLifecycleEventKind
COMPONENT_LIFECYCLE_EVENT_KIND_COMPONENT_INITIALIZING → const ComponentLifecycleEventKind
COMPONENT_LIFECYCLE_EVENT_KIND_COMPONENT_READY → const ComponentLifecycleEventKind
COMPONENT_LIFECYCLE_EVENT_KIND_DOWNLOAD_PROGRESS → const ComponentLifecycleEventKind
COMPONENT_LIFECYCLE_EVENT_KIND_INITIALIZATION_COMPLETED → const ComponentLifecycleEventKind
COMPONENT_LIFECYCLE_EVENT_KIND_INITIALIZATION_STARTED → const ComponentLifecycleEventKind
Absorbed from ComponentInitializationEventKind.
COMPONENT_LIFECYCLE_EVENT_KIND_MODEL_DELETE_COMPLETED → const ComponentLifecycleEventKind
COMPONENT_LIFECYCLE_EVENT_KIND_MODEL_LOAD_COMPLETED → const ComponentLifecycleEventKind
COMPONENT_LIFECYCLE_EVENT_KIND_MODEL_UNLOAD_COMPLETED → const ComponentLifecycleEventKind
COMPONENT_LIFECYCLE_EVENT_KIND_PARALLEL_INIT_STARTED → const ComponentLifecycleEventKind
COMPONENT_LIFECYCLE_EVENT_KIND_SEQUENTIAL_INIT_STARTED → const ComponentLifecycleEventKind
COMPONENT_LIFECYCLE_EVENT_KIND_SNAPSHOT → const ComponentLifecycleEventKind
COMPONENT_LIFECYCLE_EVENT_KIND_SNAPSHOT_RESULT → const ComponentLifecycleEventKind
COMPONENT_LIFECYCLE_EVENT_KIND_SOME_COMPONENTS_READY → const ComponentLifecycleEventKind
COMPONENT_LIFECYCLE_EVENT_KIND_STATE_CHANGED → const ComponentLifecycleEventKind
COMPONENT_LIFECYCLE_EVENT_KIND_STORAGE_AVAILABILITY → const ComponentLifecycleEventKind
COMPONENT_LIFECYCLE_EVENT_KIND_STORAGE_DELETE_COMPLETED → const ComponentLifecycleEventKind
COMPONENT_LIFECYCLE_EVENT_KIND_STORAGE_DELETE_PLAN → const ComponentLifecycleEventKind
COMPONENT_LIFECYCLE_EVENT_KIND_UNSPECIFIED → const ComponentLifecycleEventKind
values → const List<ComponentLifecycleEventKind>