ConfigurationEventKind class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → ConfigurationEventKind?
Constants
- CONFIGURATION_EVENT_KIND_ANALYTICS_STATUS_REQUESTED → const ConfigurationEventKind
- CONFIGURATION_EVENT_KIND_ANALYTICS_STATUS_RETRIEVED → const ConfigurationEventKind
- CONFIGURATION_EVENT_KIND_CHANGED → const ConfigurationEventKind
- CONFIGURATION_EVENT_KIND_FETCH_COMPLETED → const ConfigurationEventKind
- CONFIGURATION_EVENT_KIND_FETCH_FAILED → const ConfigurationEventKind
- CONFIGURATION_EVENT_KIND_FETCH_STARTED → const ConfigurationEventKind
- CONFIGURATION_EVENT_KIND_LOADED → const ConfigurationEventKind
- CONFIGURATION_EVENT_KIND_PRIVACY_MODE_REQUESTED → const ConfigurationEventKind
- CONFIGURATION_EVENT_KIND_PRIVACY_MODE_RETRIEVED → const ConfigurationEventKind
- CONFIGURATION_EVENT_KIND_ROUTING_POLICY_REQUESTED → const ConfigurationEventKind
- CONFIGURATION_EVENT_KIND_ROUTING_POLICY_RETRIEVED → const ConfigurationEventKind
- CONFIGURATION_EVENT_KIND_SETTINGS_REQUESTED → const ConfigurationEventKind
- CONFIGURATION_EVENT_KIND_SETTINGS_RETRIEVED → const ConfigurationEventKind
- CONFIGURATION_EVENT_KIND_SYNC_COMPLETED → const ConfigurationEventKind
- CONFIGURATION_EVENT_KIND_SYNC_FAILED → const ConfigurationEventKind
- CONFIGURATION_EVENT_KIND_SYNC_REQUESTED → const ConfigurationEventKind
- CONFIGURATION_EVENT_KIND_SYNC_STARTED → const ConfigurationEventKind
- CONFIGURATION_EVENT_KIND_UNSPECIFIED → const ConfigurationEventKind
- CONFIGURATION_EVENT_KIND_UPDATED → const ConfigurationEventKind
-
values
→ const List<
ConfigurationEventKind>