DeviceEventKind class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → DeviceEventKind?
Constants
- DEVICE_EVENT_KIND_BATTERY_CHANGED → const DeviceEventKind
- DEVICE_EVENT_KIND_CONNECTIVITY_CHANGED → const DeviceEventKind
- DEVICE_EVENT_KIND_DEVICE_INFO_COLLECTED → const DeviceEventKind
- DEVICE_EVENT_KIND_DEVICE_INFO_COLLECTION_FAILED → const DeviceEventKind
- DEVICE_EVENT_KIND_DEVICE_INFO_REFRESHED → const DeviceEventKind
- DEVICE_EVENT_KIND_DEVICE_INFO_SYNC_COMPLETED → const DeviceEventKind
- DEVICE_EVENT_KIND_DEVICE_INFO_SYNC_FAILED → const DeviceEventKind
- DEVICE_EVENT_KIND_DEVICE_INFO_SYNC_STARTED → const DeviceEventKind
- DEVICE_EVENT_KIND_DEVICE_REGISTERED → const DeviceEventKind
- DEVICE_EVENT_KIND_DEVICE_REGISTRATION_FAILED → const DeviceEventKind
- DEVICE_EVENT_KIND_DEVICE_STATE_CHANGED → const DeviceEventKind
- DEVICE_EVENT_KIND_THERMAL_CHANGED → const DeviceEventKind
- DEVICE_EVENT_KIND_UNSPECIFIED → const DeviceEventKind
-
values
→ const List<
DeviceEventKind>