DownloadEventKind class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → DownloadEventKind?
Constants
- DOWNLOAD_EVENT_KIND_CANCEL_REQUESTED → const DownloadEventKind
- DOWNLOAD_EVENT_KIND_CANCELLED → const DownloadEventKind
- DOWNLOAD_EVENT_KIND_COMPLETED → const DownloadEventKind
- DOWNLOAD_EVENT_KIND_FAILED → const DownloadEventKind
- DOWNLOAD_EVENT_KIND_PARTIAL_BYTES_DELETED → const DownloadEventKind
- DOWNLOAD_EVENT_KIND_PAUSED → const DownloadEventKind
- DOWNLOAD_EVENT_KIND_PLAN_COMPLETED → const DownloadEventKind
- DOWNLOAD_EVENT_KIND_PLAN_FAILED → const DownloadEventKind
- DOWNLOAD_EVENT_KIND_PLAN_STARTED → const DownloadEventKind
- DOWNLOAD_EVENT_KIND_PROGRESS → const DownloadEventKind
- DOWNLOAD_EVENT_KIND_RESUME_REQUESTED → const DownloadEventKind
- DOWNLOAD_EVENT_KIND_RESUMED → const DownloadEventKind
- DOWNLOAD_EVENT_KIND_STARTED → const DownloadEventKind
- DOWNLOAD_EVENT_KIND_UNSPECIFIED → const DownloadEventKind
-
values
→ const List<
DownloadEventKind>