GenerationEventKind class

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) GenerationEventKind?

Constants

GENERATION_EVENT_KIND_CANCEL_REQUESTED → const GenerationEventKind
GENERATION_EVENT_KIND_CANCELLED → const GenerationEventKind
GENERATION_EVENT_KIND_COMPLETED → const GenerationEventKind
GENERATION_EVENT_KIND_COST_CALCULATED → const GenerationEventKind
GENERATION_EVENT_KIND_FAILED → const GenerationEventKind
GENERATION_EVENT_KIND_FIRST_TOKEN_GENERATED → const GenerationEventKind
GENERATION_EVENT_KIND_MODEL_LOADED → const GenerationEventKind
GENERATION_EVENT_KIND_MODEL_UNLOADED → const GenerationEventKind
GENERATION_EVENT_KIND_ROUTING_DECISION → const GenerationEventKind
GENERATION_EVENT_KIND_SESSION_ENDED → const GenerationEventKind
GENERATION_EVENT_KIND_SESSION_STARTED → const GenerationEventKind
GENERATION_EVENT_KIND_STARTED → const GenerationEventKind
GENERATION_EVENT_KIND_STREAM_COMPLETED → const GenerationEventKind
GENERATION_EVENT_KIND_STREAMING_UPDATE → const GenerationEventKind
GENERATION_EVENT_KIND_STRUCTURED_OUTPUT_COMPLETED → const GenerationEventKind
GENERATION_EVENT_KIND_STRUCTURED_OUTPUT_FAILED → const GenerationEventKind
GENERATION_EVENT_KIND_STRUCTURED_OUTPUT_STARTED → const GenerationEventKind
GENERATION_EVENT_KIND_THINKING_COMPLETED → const GenerationEventKind
GENERATION_EVENT_KIND_THINKING_DELTA → const GenerationEventKind
GENERATION_EVENT_KIND_THINKING_STARTED → const GenerationEventKind
GENERATION_EVENT_KIND_TOKEN_GENERATED → const GenerationEventKind
GENERATION_EVENT_KIND_TOOL_CALL_COMPLETED → const GenerationEventKind
GENERATION_EVENT_KIND_TOOL_CALL_FAILED → const GenerationEventKind
GENERATION_EVENT_KIND_TOOL_CALL_STARTED → const GenerationEventKind
GENERATION_EVENT_KIND_UNSPECIFIED → const GenerationEventKind
values → const List<GenerationEventKind>