ModelEventKind class

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) ModelEventKind?

Constants

MODEL_EVENT_KIND_ASSIGNMENT_COMPLETED → const ModelEventKind
MODEL_EVENT_KIND_ASSIGNMENT_FAILED → const ModelEventKind
MODEL_EVENT_KIND_ASSIGNMENT_STARTED → const ModelEventKind
MODEL_EVENT_KIND_BUILT_IN_REGISTERED → const ModelEventKind
MODEL_EVENT_KIND_CATALOG_LOADED → const ModelEventKind
MODEL_EVENT_KIND_CURRENT_MODEL_CHANGED → const ModelEventKind
MODEL_EVENT_KIND_CUSTOM_MODEL_ADDED → const ModelEventKind
MODEL_EVENT_KIND_DELETE_COMPLETED → const ModelEventKind
MODEL_EVENT_KIND_DELETE_FAILED → const ModelEventKind
MODEL_EVENT_KIND_DELETE_STARTED → const ModelEventKind
MODEL_EVENT_KIND_DISCOVERY_COMPLETED → const ModelEventKind
MODEL_EVENT_KIND_DISCOVERY_FAILED → const ModelEventKind
MODEL_EVENT_KIND_DISCOVERY_STARTED → const ModelEventKind
MODEL_EVENT_KIND_DOWNLOAD_CANCEL_REQUESTED → const ModelEventKind
MODEL_EVENT_KIND_DOWNLOAD_CANCELLED → const ModelEventKind
MODEL_EVENT_KIND_DOWNLOAD_COMPLETED → const ModelEventKind
MODEL_EVENT_KIND_DOWNLOAD_FAILED → const ModelEventKind
MODEL_EVENT_KIND_DOWNLOAD_PARTIAL_BYTES_DELETED → const ModelEventKind
MODEL_EVENT_KIND_DOWNLOAD_PAUSED → const ModelEventKind
MODEL_EVENT_KIND_DOWNLOAD_PLAN_COMPLETED → const ModelEventKind
MODEL_EVENT_KIND_DOWNLOAD_PLAN_FAILED → const ModelEventKind
MODEL_EVENT_KIND_DOWNLOAD_PLAN_STARTED → const ModelEventKind
Absorbed from DownloadEventKind.
MODEL_EVENT_KIND_DOWNLOAD_PROGRESS → const ModelEventKind
MODEL_EVENT_KIND_DOWNLOAD_RESUME_REQUESTED → const ModelEventKind
MODEL_EVENT_KIND_DOWNLOAD_RESUMED → const ModelEventKind
MODEL_EVENT_KIND_DOWNLOAD_STARTED → const ModelEventKind
MODEL_EVENT_KIND_EXTRACTION_COMPLETED → const ModelEventKind
MODEL_EVENT_KIND_EXTRACTION_FAILED → const ModelEventKind
MODEL_EVENT_KIND_EXTRACTION_PROGRESS → const ModelEventKind
MODEL_EVENT_KIND_EXTRACTION_STARTED → const ModelEventKind
MODEL_EVENT_KIND_IMPORT_COMPLETED → const ModelEventKind
MODEL_EVENT_KIND_IMPORT_FAILED → const ModelEventKind
MODEL_EVENT_KIND_IMPORT_STARTED → const ModelEventKind
MODEL_EVENT_KIND_LIST_COMPLETED → const ModelEventKind
MODEL_EVENT_KIND_LIST_FAILED → const ModelEventKind
MODEL_EVENT_KIND_LOAD_COMPLETED → const ModelEventKind
MODEL_EVENT_KIND_LOAD_FAILED → const ModelEventKind
MODEL_EVENT_KIND_LOAD_PROGRESS → const ModelEventKind
MODEL_EVENT_KIND_LOAD_STARTED → const ModelEventKind
MODEL_EVENT_KIND_REGISTRY_GET_COMPLETED → const ModelEventKind
MODEL_EVENT_KIND_REGISTRY_GET_FAILED → const ModelEventKind
MODEL_EVENT_KIND_REGISTRY_LIST_COMPLETED → const ModelEventKind
MODEL_EVENT_KIND_REGISTRY_LIST_FAILED → const ModelEventKind
MODEL_EVENT_KIND_REGISTRY_REFRESH_COMPLETED → const ModelEventKind
MODEL_EVENT_KIND_REGISTRY_REFRESH_FAILED → const ModelEventKind
MODEL_EVENT_KIND_REGISTRY_REFRESH_STARTED → const ModelEventKind
Absorbed from ModelRegistryEventKind.
MODEL_EVENT_KIND_UNLOAD_COMPLETED → const ModelEventKind
MODEL_EVENT_KIND_UNLOAD_FAILED → const ModelEventKind
MODEL_EVENT_KIND_UNLOAD_STARTED → const ModelEventKind
MODEL_EVENT_KIND_UNSPECIFIED → const ModelEventKind
values → const List<ModelEventKind>