ModelRegistryEventKind class

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) ModelRegistryEventKind?

Constants

MODEL_REGISTRY_EVENT_KIND_ASSIGNMENT_COMPLETED → const ModelRegistryEventKind
MODEL_REGISTRY_EVENT_KIND_ASSIGNMENT_FAILED → const ModelRegistryEventKind
MODEL_REGISTRY_EVENT_KIND_ASSIGNMENT_STARTED → const ModelRegistryEventKind
MODEL_REGISTRY_EVENT_KIND_CURRENT_MODEL_CHANGED → const ModelRegistryEventKind
MODEL_REGISTRY_EVENT_KIND_DISCOVERY_COMPLETED → const ModelRegistryEventKind
MODEL_REGISTRY_EVENT_KIND_DISCOVERY_FAILED → const ModelRegistryEventKind
MODEL_REGISTRY_EVENT_KIND_DISCOVERY_STARTED → const ModelRegistryEventKind
MODEL_REGISTRY_EVENT_KIND_GET_COMPLETED → const ModelRegistryEventKind
MODEL_REGISTRY_EVENT_KIND_GET_FAILED → const ModelRegistryEventKind
MODEL_REGISTRY_EVENT_KIND_GET_STARTED → const ModelRegistryEventKind
MODEL_REGISTRY_EVENT_KIND_IMPORT_COMPLETED → const ModelRegistryEventKind
MODEL_REGISTRY_EVENT_KIND_IMPORT_FAILED → const ModelRegistryEventKind
MODEL_REGISTRY_EVENT_KIND_IMPORT_STARTED → const ModelRegistryEventKind
MODEL_REGISTRY_EVENT_KIND_LIST_COMPLETED → const ModelRegistryEventKind
MODEL_REGISTRY_EVENT_KIND_LIST_FAILED → const ModelRegistryEventKind
MODEL_REGISTRY_EVENT_KIND_LIST_STARTED → const ModelRegistryEventKind
MODEL_REGISTRY_EVENT_KIND_REFRESH_COMPLETED → const ModelRegistryEventKind
MODEL_REGISTRY_EVENT_KIND_REFRESH_FAILED → const ModelRegistryEventKind
MODEL_REGISTRY_EVENT_KIND_REFRESH_STARTED → const ModelRegistryEventKind
MODEL_REGISTRY_EVENT_KIND_UNSPECIFIED → const ModelRegistryEventKind
values → const List<ModelRegistryEventKind>