StorageEventKind class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → StorageEventKind?
Constants
- STORAGE_EVENT_KIND_CACHE_HIT → const StorageEventKind
- STORAGE_EVENT_KIND_CACHE_MISS → const StorageEventKind
- STORAGE_EVENT_KIND_CLEAN_TEMP_COMPLETED → const StorageEventKind
- STORAGE_EVENT_KIND_CLEAN_TEMP_FAILED → const StorageEventKind
- STORAGE_EVENT_KIND_CLEAN_TEMP_STARTED → const StorageEventKind
- STORAGE_EVENT_KIND_CLEAR_CACHE_COMPLETED → const StorageEventKind
- STORAGE_EVENT_KIND_CLEAR_CACHE_FAILED → const StorageEventKind
- STORAGE_EVENT_KIND_CLEAR_CACHE_STARTED → const StorageEventKind
- STORAGE_EVENT_KIND_DELETE_MODEL_COMPLETED → const StorageEventKind
- STORAGE_EVENT_KIND_DELETE_MODEL_FAILED → const StorageEventKind
- STORAGE_EVENT_KIND_DELETE_MODEL_STARTED → const StorageEventKind
- STORAGE_EVENT_KIND_DISK_FULL → const StorageEventKind
- STORAGE_EVENT_KIND_EVICTION → const StorageEventKind
- STORAGE_EVENT_KIND_INFO_REQUESTED → const StorageEventKind
- STORAGE_EVENT_KIND_INFO_RETRIEVED → const StorageEventKind
- STORAGE_EVENT_KIND_MODELS_REQUESTED → const StorageEventKind
- STORAGE_EVENT_KIND_MODELS_RETRIEVED → const StorageEventKind
- STORAGE_EVENT_KIND_UNSPECIFIED → const StorageEventKind
-
values
→ const List<
StorageEventKind>