StorageLifecycleEventKind class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → StorageLifecycleEventKind?
Constants
- STORAGE_LIFECYCLE_EVENT_KIND_AVAILABILITY_CHECKED → const StorageLifecycleEventKind
- STORAGE_LIFECYCLE_EVENT_KIND_AVAILABILITY_FAILED → const StorageLifecycleEventKind
- STORAGE_LIFECYCLE_EVENT_KIND_CACHE_CLEANUP_COMPLETED → const StorageLifecycleEventKind
- STORAGE_LIFECYCLE_EVENT_KIND_CACHE_CLEANUP_FAILED → const StorageLifecycleEventKind
- STORAGE_LIFECYCLE_EVENT_KIND_CACHE_CLEANUP_STARTED → const StorageLifecycleEventKind
- STORAGE_LIFECYCLE_EVENT_KIND_DELETE_COMPLETED → const StorageLifecycleEventKind
- STORAGE_LIFECYCLE_EVENT_KIND_DELETE_DRY_RUN_COMPLETED → const StorageLifecycleEventKind
- STORAGE_LIFECYCLE_EVENT_KIND_DELETE_FAILED → const StorageLifecycleEventKind
- STORAGE_LIFECYCLE_EVENT_KIND_DELETE_PLAN_CREATED → const StorageLifecycleEventKind
- STORAGE_LIFECYCLE_EVENT_KIND_DELETE_PLAN_FAILED → const StorageLifecycleEventKind
- STORAGE_LIFECYCLE_EVENT_KIND_DELETE_STARTED → const StorageLifecycleEventKind
- STORAGE_LIFECYCLE_EVENT_KIND_INFO_COMPLETED → const StorageLifecycleEventKind
- STORAGE_LIFECYCLE_EVENT_KIND_INFO_STARTED → const StorageLifecycleEventKind
- STORAGE_LIFECYCLE_EVENT_KIND_UNSPECIFIED → const StorageLifecycleEventKind
-
values
→ const List<
StorageLifecycleEventKind>