RAGConfig class
RAG — retrieve → rerank → prompt → LLM.
- Available extensions
Constructors
- RAGConfig({String? embedModelId, String? rerankModelId, String? llmModelId, VectorStore? vectorStore, String? vectorStorePath, int? retrieveK, int? rerankTop, double? bm25K1, double? bm25B, int? rrfK, String? promptTemplate, SolutionType? typeKind})
-
factory
-
RAGConfig.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- RAGConfig.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- bm25B ↔ double
-
getter/setter pair
- bm25K1 ↔ double
-
BM25 parameters.
getter/setter pair
- embedModelId ↔ String
-
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setter
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - llmModelId ↔ String
-
getter/setter pair
- promptTemplate ↔ String
-
Prompt template. Supports {{context}} and {{query}} placeholders.
getter/setter pair
- rerankModelId ↔ String
-
getter/setter pair
- rerankTop ↔ int
-
getter/setter pair
- retrieveK ↔ int
-
getter/setter pair
- rrfK ↔ int
-
RRF fusion parameter.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typeKind ↔ SolutionType
-
Optional explicit solution-kind tag. See
SolutionType.getter/setter pair - unknownFields → UnknownFieldSet
-
no setterinherited
- vectorStore ↔ VectorStore
-
Vector store — USearch (in-process HNSW, default) or remote pgvector.
getter/setter pair
- vectorStorePath ↔ String
-
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearBm25B(
) → void -
clearBm25K1(
) → void -
clearEmbedModelId(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearLlmModelId(
) → void -
clearPromptTemplate(
) → void -
clearRerankModelId(
) → void -
clearRerankTop(
) → void -
clearRetrieveK(
) → void -
clearRrfK(
) → void -
clearTypeKind(
) → void -
clearVectorStore(
) → void -
clearVectorStorePath(
) → void -
clone(
) → RAGConfig - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(RAGConfig)) → RAGConfig -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → RAGConfig - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasBm25B(
) → bool -
hasBm25K1(
) → bool -
hasEmbedModelId(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasLlmModelId(
) → bool -
hasPromptTemplate(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasRerankModelId(
) → bool -
hasRerankTop(
) → bool -
hasRetrieveK(
) → bool -
hasRrfK(
) → bool -
hasTypeKind(
) → bool -
hasVectorStore(
) → bool -
hasVectorStorePath(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → RAGConfig -
getDefault(
) → RAGConfig