enumValues property
Allowed enum values (enum in JSON Schema). Strings only; numeric and
boolean enums are rare and serialized as strings here.
Implementation
@$pb.TagNumber(3)
$pb.PbList<$core.String> get enumValues => $_getList(2);
Allowed enum values (enum in JSON Schema). Strings only; numeric and
boolean enums are rare and serialized as strings here.
@$pb.TagNumber(3)
$pb.PbList<$core.String> get enumValues => $_getList(2);