isValid property
Whether the parsed output validates against the requested schema.
Implementation
@$pb.TagNumber(1)
$core.bool get isValid => $_getBF(0);
Implementation
@$pb.TagNumber(1)
set isValid($core.bool value) => $_setBool(0, value);
Whether the parsed output validates against the requested schema.
@$pb.TagNumber(1)
$core.bool get isValid => $_getBF(0);
@$pb.TagNumber(1)
set isValid($core.bool value) => $_setBool(0, value);