sampleRate property

  1. @TagNumber.new(3)
int get sampleRate

Sample rate in Hz. For PCM payloads this is required to interpret the bytes; for compressed formats (mp3, opus, …) it reflects the synthesis sample rate, not the container rate.

Implementation

@$pb.TagNumber(3)
$core.int get sampleRate => $_getIZ(2);
  1. @TagNumber.new(3)
set sampleRate (int value)

Implementation

@$pb.TagNumber(3)
set sampleRate($core.int value) => $_setSignedInt32(2, value);