messages property
Ordered conversation. A follow-up question about the same picture is just another turn; images ride as ChatMessage.attachments.
Implementation
@$pb.TagNumber(8)
$pb.PbList<$0.ChatMessage> get messages => $_getList(5);
Ordered conversation. A follow-up question about the same picture is just another turn; images ride as ChatMessage.attachments.
@$pb.TagNumber(8)
$pb.PbList<$0.ChatMessage> get messages => $_getList(5);