generated/voice_agent_service.pb library

Classes

AudioPipelineConfig
VoiceAgentApi
VoiceAgentComposeConfig
VoiceAgentRequest
Empty request type — the voice agent already has its config set via rac_voice_agent_init() at handle creation time. The Stream rpc just opens a new event subscription on an existing handle.
VoiceAgentResult
VoiceAgentSynthesizeSpeechProtoRequest
VoiceAgentTranscribeProtoRequest
Helper-level proto requests for voice-agent sub-components.
VoiceAgentTurnRequest
VoiceSessionConfig

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.