VoiceEvent class
Sum type emitted on the output edge of the VoiceAgent pipeline.
- Available extensions
Constructors
-
VoiceEvent({Int64? seq, Int64? timestampUs, EventCategory? category, ErrorSeverity? severity, VoicePipelineComponent? component, UserSaidEvent? userSaid, AssistantTokenEvent? assistantToken, AudioFrameEvent? audio, VADEvent? vad, InterruptedEvent? interrupted, StateChangeEvent? state, ErrorEvent? error, MetricsEvent? metrics, VoiceAgentComponentStates? componentStateChanged, VoiceSessionError? sessionError, SessionStartedEvent? sessionStarted, SessionStoppedEvent? sessionStopped, AgentResponseStartedEvent? agentResponseStarted, AgentResponseCompletedEvent? agentResponseCompleted, SpeechTurnDetectionEvent? speechTurnDetection, TurnLifecycleEvent? turnLifecycle, WakeWordDetectedEvent? wakewordDetected, AudioLevelEvent? audioLevel, ComponentProgressEvent? componentProgress, String? sessionId, String? turnId, String? requestId, Iterable<
MapEntry< ? metadata})String, String> > -
factory
-
VoiceEvent.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- VoiceEvent.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- agentResponseCompleted ↔ AgentResponseCompletedEvent
-
getter/setter pair
- agentResponseStarted ↔ AgentResponseStartedEvent
-
getter/setter pair
- assistantToken ↔ AssistantTokenEvent
-
getter/setter pair
- audio ↔ AudioFrameEvent
-
getter/setter pair
- audioLevel ↔ AudioLevelEvent
-
getter/setter pair
- category ↔ EventCategory
-
getter/setter pair
- component ↔ VoicePipelineComponent
-
getter/setter pair
- componentProgress ↔ ComponentProgressEvent
-
getter/setter pair
- componentStateChanged ↔ VoiceAgentComponentStates
-
Voice agent lifecycle events. Mirror Swift VoiceSessionError /
VoiceAgentComponentStates and the AsyncSequence-style lifecycle
signals consumed by the cross-platform VoiceAgent extensions
(Swift VoiceAgentTypes.swift, Kotlin VoiceAgentTypes.kt, RN
VoiceAgentTypes.ts, Web VoiceAgentCTypes.ts, Flutter
voice_agent_types.dart).
getter/setter pair
- error ↔ ErrorEvent
-
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setter
- interrupted ↔ InterruptedEvent
-
getter/setter pair
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited -
metadata
→ PbMap<
String, String> -
no setter
- metrics ↔ MetricsEvent
-
getter/setter pair
- requestId ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seq ↔ Int64
-
Monotonic pipeline-local sequence number. Useful for frontends that
need to detect gaps after reconnection or out-of-order delivery.
getter/setter pair
- sessionError ↔ VoiceSessionError
-
getter/setter pair
- sessionId ↔ String
-
Correlation fields shared by streaming and one-shot voice turns.
getter/setter pair
- sessionStarted ↔ SessionStartedEvent
-
getter/setter pair
- sessionStopped ↔ SessionStoppedEvent
-
getter/setter pair
- severity ↔ ErrorSeverity
-
getter/setter pair
- speechTurnDetection ↔ SpeechTurnDetectionEvent
-
getter/setter pair
- state ↔ StateChangeEvent
-
getter/setter pair
- timestampUs ↔ Int64
-
Wall-clock timestamp captured at the C++ edge, in microseconds since
Unix epoch. Frontends may re-timestamp for UI display.
getter/setter pair
- turnId ↔ String
-
getter/setter pair
- turnLifecycle ↔ TurnLifecycleEvent
-
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
- userSaid ↔ UserSaidEvent
-
getter/setter pair
- vad ↔ VADEvent
-
getter/setter pair
- wakewordDetected ↔ WakeWordDetectedEvent
-
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearAgentResponseCompleted(
) → void -
clearAgentResponseStarted(
) → void -
clearAssistantToken(
) → void -
clearAudio(
) → void -
clearAudioLevel(
) → void -
clearCategory(
) → void -
clearComponent(
) → void -
clearComponentProgress(
) → void -
clearComponentStateChanged(
) → void -
clearError(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearInterrupted(
) → void -
clearMetrics(
) → void -
clearPayload(
) → void -
clearRequestId(
) → void -
clearSeq(
) → void -
clearSessionError(
) → void -
clearSessionId(
) → void -
clearSessionStarted(
) → void -
clearSessionStopped(
) → void -
clearSeverity(
) → void -
clearSpeechTurnDetection(
) → void -
clearState(
) → void -
clearTimestampUs(
) → void -
clearTurnId(
) → void -
clearTurnLifecycle(
) → void -
clearUserSaid(
) → void -
clearVad(
) → void -
clearWakewordDetected(
) → void -
clone(
) → VoiceEvent - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(VoiceEvent)) → VoiceEvent -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → VoiceEvent - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureAgentResponseCompleted(
) → AgentResponseCompletedEvent -
ensureAgentResponseStarted(
) → AgentResponseStartedEvent -
ensureAssistantToken(
) → AssistantTokenEvent -
ensureAudio(
) → AudioFrameEvent -
ensureAudioLevel(
) → AudioLevelEvent -
ensureComponentProgress(
) → ComponentProgressEvent -
ensureComponentStateChanged(
) → VoiceAgentComponentStates -
ensureError(
) → ErrorEvent -
ensureInterrupted(
) → InterruptedEvent -
ensureMetrics(
) → MetricsEvent -
ensureSessionError(
) → VoiceSessionError -
ensureSessionStarted(
) → SessionStartedEvent -
ensureSessionStopped(
) → SessionStoppedEvent -
ensureSpeechTurnDetection(
) → SpeechTurnDetectionEvent -
ensureState(
) → StateChangeEvent -
ensureTurnLifecycle(
) → TurnLifecycleEvent -
ensureUserSaid(
) → UserSaidEvent -
ensureVad(
) → VADEvent -
ensureWakewordDetected(
) → WakeWordDetectedEvent -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasAgentResponseCompleted(
) → bool -
hasAgentResponseStarted(
) → bool -
hasAssistantToken(
) → bool -
hasAudio(
) → bool -
hasAudioLevel(
) → bool -
hasCategory(
) → bool -
hasComponent(
) → bool -
hasComponentProgress(
) → bool -
hasComponentStateChanged(
) → bool -
hasError(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasInterrupted(
) → bool -
hasMetrics(
) → bool -
hasRequestId(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasSeq(
) → bool -
hasSessionError(
) → bool -
hasSessionId(
) → bool -
hasSessionStarted(
) → bool -
hasSessionStopped(
) → bool -
hasSeverity(
) → bool -
hasSpeechTurnDetection(
) → bool -
hasState(
) → bool -
hasTimestampUs(
) → bool -
hasTurnId(
) → bool -
hasTurnLifecycle(
) → bool -
hasUserSaid(
) → bool -
hasVad(
) → bool -
hasWakewordDetected(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
whichPayload(
) → VoiceEvent_Payload -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → VoiceEvent -
getDefault(
) → VoiceEvent