LLMGenerationResult class

Result of LLM text generation Matches Swift's LLMGenerationResult

Constructors

LLMGenerationResult({required String text, String? thinkingContent, required int inputTokens, required int tokensUsed, required String modelUsed, required double latencyMs, String? framework, required double tokensPerSecond, double? timeToFirstTokenMs, int thinkingTokens = 0, int responseTokens = 0, Map<String, dynamic>? structuredData})
const

Properties

framework String?
final
hashCode int
The hash code for this object.
no setterinherited
inputTokens int
final
latencyMs double
final
modelUsed String
final
responseTokens int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structuredData Map<String, dynamic>?
final
text String
final
thinkingContent String?
final
thinkingTokens int
final
timeToFirstTokenMs double?
final
tokensPerSecond double
final
tokensUsed int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited