ModelDownloadProgress class

Download progress information

Constructors

ModelDownloadProgress({required String modelId, required int bytesDownloaded, required int totalBytes, required ModelDownloadStage stage, required double overallProgress, String? error})
const
ModelDownloadProgress.completed(String modelId)
factory
ModelDownloadProgress.downloading(String modelId, int downloaded, int total)
factory
ModelDownloadProgress.extracting(String modelId)
factory
ModelDownloadProgress.failed(String modelId, String error)
factory
ModelDownloadProgress.started(String modelId, int totalBytes)
factory

Properties

bytesDownloaded int
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
modelId String
final
overallProgress double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stage ModelDownloadStage
final
totalBytes int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited