ModelFileDescriptor class

Describes a file that needs to be downloaded as part of a multi-file model.

Matches Swift ModelFileDescriptor from Public/Extensions/Models/ModelTypes.swift.

Constructors

ModelFileDescriptor({required String relativePath, required String destinationPath, bool isRequired = true, Uri? url})
const
ModelFileDescriptor.fromJson(Map<String, dynamic> json)
factory

Properties

destinationPath String
final
hashCode int
The hash code for this object.
no setterinherited
isRequired bool
final
relativePath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url Uri?
The individual download URL for this file.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited