url property
The individual download URL for this file.
When set, the download service fetches this specific URL instead of deriving the URL from the parent model's downloadURL.
Implementation
final Uri? url;
The individual download URL for this file.
When set, the download service fetches this specific URL instead of deriving the URL from the parent model's downloadURL.
final Uri? url;