RacDeviceRegistrationInfoStruct class base

Device registration info struct matching rac_device_registration_info_t

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
architecture Pointer<Utf8>
getter/setter pair
availableMemory int
getter/setter pair
batteryLevel double
getter/setter pair
batteryState Pointer<Utf8>
getter/setter pair
chipName Pointer<Utf8>
getter/setter pair
coreCount int
getter/setter pair
deviceFingerprint Pointer<Utf8>
getter/setter pair
deviceId Pointer<Utf8>
getter/setter pair
deviceModel Pointer<Utf8>
getter/setter pair
deviceName Pointer<Utf8>
getter/setter pair
efficiencyCores int
getter/setter pair
formFactor Pointer<Utf8>
getter/setter pair
gpuFamily Pointer<Utf8>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasNeuralEngine int
getter/setter pair
isLowPowerMode int
getter/setter pair
neuralEngineCores int
getter/setter pair
osVersion Pointer<Utf8>
getter/setter pair
performanceCores int
getter/setter pair
platform Pointer<Utf8>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalMemory int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited