DartBridgeDiarization class
Bridge over rac_diarization_diarize_lifecycle_proto.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
diarize(
DiarizationRequest request) → DiarizationResult -
Diarize
requestthrough the lifecycle-owned commons ABI. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
Process-wide bridge instance.
final