ModelPathResolution class

Constructors

ModelPathResolution({required String? rootPath, required String? primaryModelPath, required String? mmprojPath, required String? tokenizerPath, required String? configPath, required bool isDirectoryBased, required bool isComplete})
const

Properties

configPath String?
final
hashCode int
The hash code for this object.
no setterinherited
isComplete bool
final
isDirectoryBased bool
final
mmprojPath String?
final
primaryModelPath String?
final
rootPath String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenizerPath String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited