RacModelPathResolutionStruct class base

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
checksumMatched int
getter/setter pair
checksumValidated int
getter/setter pair
configPath Pointer<Utf8>
getter/setter pair
fileCount int
getter/setter pair
files Pointer<RacResolvedModelFileStruct>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isComplete int
getter/setter pair
isDirectoryBased int
getter/setter pair
missingRequiredFileCount int
getter/setter pair
missingRequiredFiles Pointer<Pointer<Utf8>>
getter/setter pair
mmprojPath Pointer<Utf8>
getter/setter pair
primaryModelPath Pointer<Utf8>
getter/setter pair
rootPath Pointer<Utf8>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenizerPath Pointer<Utf8>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited