DiscoveryResult class

Discovery result

Constructors

DiscoveryResult({required List<DiscoveredModel> discoveredModels, required int unregisteredCount})
const

Properties

discoveredModels List<DiscoveredModel>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unregisteredCount int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited