ModelInfo class

Model info data class

Constructors

ModelInfo({required String id, required String name, required int category, required int format, required int framework, required int source, required int sizeBytes, String? downloadURL, String? localPath, String? version})
const

Properties

category int
final
downloadURL String?
final
format int
final
framework int
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isDownloaded bool
no setter
localPath String?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeBytes int
final
source int
final
version String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited