RacArtifactInfoStruct class base
Artifact info struct matching C++ rac_model_artifact_info_t Used as nested struct in RacModelInfoCStruct
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - archiveStructure ↔ int
-
getter/setter pair
- archiveType ↔ int
-
getter/setter pair
-
expectedFiles
↔ Pointer<
Void> -
getter/setter pair
- fileDescriptorCount ↔ int
-
getter/setter pair
-
fileDescriptors
↔ Pointer<
Void> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
strategyId
↔ Pointer<
Utf8> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited