DartBridgePlatformServices class

Platform services bridge for Foundation Models and System TTS. Matches Swift's CppBridge+Platform.swift.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAvailableServices() List<String>
Get available platform services
isFoundationModelsAvailable() bool
Check if Foundation Models are available (iOS 18+)
isSystemSTTAvailable() bool
Check if System STT is available
isSystemTTSAvailable() bool
Check if System TTS is available
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance DartBridgePlatformServices
final

Static Methods

register() Future<void>
Register platform services with C++