PluginLoadResult class
Result of loading a plugin: registered name + return code (0 ok).
Constructors
- PluginLoadResult({required String name, required int resultCode})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- resultCode → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited