DartBridgeSegmentation class

Bridge over rac_segmentation_segment_lifecycle_proto.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
segment(SegmentationRequest request) SegmentationResult
Segment request through the lifecycle-owned commons ABI.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

shared DartBridgeSegmentation
Process-wide bridge instance.
final