SolutionFfiResult class

Constructors

SolutionFfiResult({required int resultCode, SolutionNativeHandle? handle})

Properties

handle SolutionNativeHandle?
final
hashCode int
The hash code for this object.
no setterinherited
resultCode int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited