DartBridgeStorage class

Storage bridge for C++ storage operations. Matches Swift's CppBridge+Storage.swift.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

availabilityProto(StorageAvailabilityRequest request) Future<StorageAvailabilityResult>
clear() Future<bool>
Clear all storage
delete(String key) Future<bool>
Delete value from storage
deletePlanProto(StorageDeletePlanRequest request) Future<StorageDeletePlan>
deleteProto(StorageDeleteRequest request) Future<StorageDeleteResult>
exists(String key) Future<bool>
Check if key exists in storage
get(String key) Future<String?>
Get value from storage
infoProto([StorageInfoRequest? request]) Future<StorageInfoResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String key, String value) Future<bool>
Set value in storage
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance DartBridgeStorage
final