DartBridgeStructuredOutput class
Thin C ABI bridge for structured-output parse / prepare-prompt.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
makeParseRequest(
{required String text, required String schema, String requestId = ''}) → StructuredOutputParseRequest -
Build a
StructuredOutputParseRequestfor the given text + schema. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
StructuredOutputParseRequest request) → StructuredOutputResult - Parse structured output from raw model text via commons.
-
preparePrompt(
{required String prompt, required StructuredOutputOptions options, String requestId = ''}) → StructuredOutputPromptResult - Build the schema-instrumented prompt for structured output via commons.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
final