RacSearchResultStruct class base

Search result from vector retrieval matching rac_search_result_t

Inheritance
Implemented types
Available extensions

Constructors

RacSearchResultStruct()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
chunkId Pointer<Utf8>
Chunk ID (caller must free)
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
metadataJson Pointer<Utf8>
Metadata JSON (caller must free)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
similarityScore double
Cosine similarity (0.0-1.0)
getter/setter pair
text Pointer<Utf8>
Chunk text (caller must free)
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited