RacToolCallStruct class base
Parsed tool call from LLM output - matches rac_tool_call_t
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
argumentsJson
↔ Pointer<
Utf8> -
getter/setter pair
- callId ↔ int
-
getter/setter pair
-
cleanText
↔ Pointer<
Utf8> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasToolCall ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
toolName
↔ Pointer<
Utf8> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited