RacToolCallingOptionsStruct class base

Tool calling options - matches rac_tool_calling_options_t

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
autoExecute int
getter/setter pair
format int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
keepToolsAvailable int
getter/setter pair
maxTokens int
getter/setter pair
maxToolCalls int
getter/setter pair
replaceSystemPrompt int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemPrompt Pointer<Utf8>
getter/setter pair
temperature double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited