RacToolParamType class abstract

Tool parameter type enum values - matches rac_tool_param_type_t

Constructors

RacToolParamType()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

array → const int
boolean → const int
number → const int
object → const int
string → const int