RacVlmImageStruct class base

VLM image input structure (matches rac_vlm_image_t)

Inheritance
Implemented types
Available extensions

Constructors

RacVlmImageStruct()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
base64Data Pointer<Utf8>
getter/setter pair
dataSize int
getter/setter pair
filePath Pointer<Utf8>
getter/setter pair
format int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height int
getter/setter pair
pixelData Pointer<Uint8>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited