RacVlmOptionsStruct class base
VLM generation options (matches rac_vlm_options_t)
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- maxImageSize ↔ int
-
getter/setter pair
- maxTokens ↔ int
-
getter/setter pair
- nThreads ↔ int
-
getter/setter pair
- numStopSequences ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stopSequences
↔ Pointer<
Pointer< Utf8> > -
getter/setter pair
- streamingEnabled ↔ int
-
getter/setter pair
-
systemPrompt
↔ Pointer<
Utf8> -
getter/setter pair
- temperature ↔ double
-
getter/setter pair
- topP ↔ double
-
getter/setter pair
- useGpu ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited