NativeFunctions class abstract
Cached native function pointers for the RACommons library.
Usage:
final result = NativeFunctions.llmIsLoaded(_handle!);
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- llmCancel → int Function(RacHandle)
-
final
- llmCleanup → int Function(RacHandle)
-
final
-
llmCreate
→ int Function(Pointer<
RacHandle> ) -
final
- llmDestroy → void Function(RacHandle)
-
final
- llmIsLoaded → int Function(RacHandle)
-
final
- llmSupportsStreaming → int Function(RacHandle)
-
final
- racFree → void Function(RacHandle)
-
final
- solutionCancel → int Function(RacHandle)
-
final
- solutionCloseInput → int Function(RacHandle)
-
final
-
solutionCreateFromProto
→ int Function(Pointer<
Void> , int, Pointer<RacHandle> ) -
final
-
solutionCreateFromYaml
→ int Function(Pointer<
Utf8> , Pointer<RacHandle> ) -
final
- solutionDestroy → void Function(RacHandle)
-
final
-
solutionFeed
→ int Function(RacHandle, Pointer<
Utf8> ) -
final
- solutionStart → int Function(RacHandle)
-
final
- solutionStop → int Function(RacHandle)
-
final
-
sttCreate
→ int Function(Pointer<
RacHandle> ) -
final
- sttDestroy → void Function(RacHandle)
-
final
- sttIsLoaded → int Function(RacHandle)
-
final
- sttSupportsStreaming → int Function(RacHandle)
-
final
-
ttsCreate
→ int Function(Pointer<
RacHandle> ) -
final
- ttsDestroy → void Function(RacHandle)
-
final
- ttsIsLoaded → int Function(RacHandle)
-
final
- ttsStop → int Function(RacHandle)
-
final
-
vadCreate
→ int Function(Pointer<
RacHandle> ) -
final
- vadDestroy → void Function(RacHandle)
-
final
- vadGetEnergyThreshold → double Function(RacHandle)
-
final
- vadIsInitialized → int Function(RacHandle)
-
final
- vadIsSpeechActive → int Function(RacHandle)
-
final
- vadSetEnergyThreshold → int Function(RacHandle, double)
-
final
- voiceAgentCleanup → int Function(RacHandle)
-
final
-
voiceAgentGenerateResponse
→ int Function(RacHandle, Pointer<
Utf8> , Pointer<Pointer< )Utf8> > -
final
- voiceAgentInitializeWithLoadedModels → int Function(RacHandle)
-
final
-
voiceAgentIsReady
→ int Function(RacHandle, Pointer<
Int32> ) -
final