RacResultCode class abstract

Error codes matching rac_error.h

Constructors

RacResultCode()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getMessage(int code) String
Get human-readable message for an error code
toProtoErrorCode(int code) ErrorCode?
Convert a C ABI result code into the generated proto error enum.

Constants

errorAbiVersionMismatch → const int
errorAdapterNotSet → const int
errorAlreadyInitialized → const int
errorAudioFormatNotSupported → const int
errorAudioSessionActivationFailed → const int
errorAudioSessionFailed → const int
errorAuthenticationFailed → const int
errorBackendBusy → const int
errorBackendInitFailed → const int
errorBackendNotFound → const int
errorBackendNotReady → const int
errorBackendUnavailable → const int
errorBufferTooSmall → const int
errorCalibrationFailed → const int
errorCalibrationTimeout → const int
errorCancelled → const int
errorCapabilityNotFound → const int
errorCapabilityUnsupported → const int
errorChecksumMismatch → const int
errorComponentNotReady → const int
errorConnectionLost → const int
errorContextTooLong → const int
errorCostLimitExceeded → const int
errorDecodingError → const int
errorDeleteFailed → const int
errorDirectoryCreationFailed → const int
errorDirectoryNotFound → const int
errorDownloadFailed → const int
errorEmptyAudioBuffer → const int
errorEmptyInput → const int
errorEncodingError → const int
errorEnvironmentMismatch → const int
errorEventInvalidCategory → const int
errorEventPublishFailed → const int
errorEventSubscriptionFailed → const int
errorExtractionFailed → const int
errorFeatureNotAvailable → const int
errorFileDeleteFailed → const int
errorFileNotFound → const int
errorFileReadFailed → const int
errorFileWriteFailed → const int
errorForbidden → const int
errorFrameworkNotAvailable → const int
errorGenerationFailed → const int
errorGenerationTimeout → const int
errorHardwareUnsupported → const int
errorHttpError → const int
errorHttpNotSupported → const int
errorHttpRequestFailed → const int
errorInferenceFailed → const int
errorInitializationFailed → const int
errorInsufficientAudioData → const int
errorInsufficientMemory → const int
errorInsufficientStorage → const int
errorInternal → const int
errorInvalidApiKey → const int
errorInvalidArgument → const int
errorInvalidConfiguration → const int
errorInvalidFileName → const int
errorInvalidFormat → const int
errorInvalidHandle → const int
errorInvalidInput → const int
errorInvalidModelFormat → const int
errorInvalidParameter → const int
errorInvalidPath → const int
errorInvalidPitch → const int
errorInvalidResponse → const int
errorInvalidSpeakingRate → const int
errorInvalidSsml → const int
errorInvalidState → const int
errorInvalidVolume → const int
errorKeychainError → const int
errorLanguageNotSupported → const int
errorMicrophonePermissionDenied → const int
errorModelIncompatible → const int
errorModelLoadFailed → const int
errorModelNotFound → const int
errorModelNotLoaded → const int
errorModelStorageCorrupted → const int
errorModelValidationFailed → const int
errorModuleAlreadyRegistered → const int
errorModuleLoadFailed → const int
errorModuleNotFound → const int
errorMoveFailed → const int
errorNetworkError → const int
errorNetworkUnavailable → const int
errorNoCapableProvider → const int
errorNotFound → const int
errorNotImplemented → const int
errorNotInitialized → const int
errorNotSupported → const int
errorNullPointer → const int
errorOutOfMemory → const int
errorPartialDownload → const int
errorPermissionDenied → const int
errorPluginBusy → const int
errorPluginDuplicate → const int
errorPluginLoadFailed → const int
errorProcessingFailed → const int
errorProviderNotFound → const int
errorRequestFailed → const int
errorRuntimeUnavailable → const int
errorSecureStorageFailed → const int
errorServerError → const int
errorServiceAlreadyRegistered → const int
errorServiceBusy → const int
errorServiceCreateFailed → const int
errorServiceNotAvailable → const int
errorServiceNotFound → const int
errorStartFailed → const int
errorStorageError → const int
errorStorageFull → const int
errorStreamCancelled → const int
errorStreamingNotSupported → const int
errorTempFileCreationFailed → const int
errorTextTooLong → const int
errorTimeout → const int
errorTokenLimitExceeded → const int
errorUnauthorized → const int
errorUnknown → const int
errorUnsupportedArchive → const int
errorUnsupportedModality → const int
errorValidationFailed → const int
errorVoiceNotAvailable → const int
success → const int