RerankApi class
Cross-encoder reranking.
Constructors
- RerankApi()
-
Bind the namespace. Reach it through
RunAnywhere.rerank.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rerank(
String query, List< String> documents, {int? topN}) → Future<List< RankedResult> > -
Score
documentsagainstquery, best first. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited