DiarizationApi class

Speaker diarization.

Constructors

DiarizationApi()
Bind the namespace. Reach it through RunAnywhere.diarization.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

diarize(AudioInput audio, {DiarizationOptions? options}) Future<DiarizationResult>
Attribute spans of audio to speakers.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited