ImagesApi class
Diffusion image generation.
Constructors
- ImagesApi()
-
Bind the namespace. Reach it through
RunAnywhere.images.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generate(
String prompt, {ImageOptions? options}) → Future< ImageResult> -
Generate an image for
prompt. -
generateStream(
String prompt, {ImageOptions? options}) → Stream< ImageEvent> -
Generate an image for
prompt, reporting progress per denoising step. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited