SegmentationApi class
Semantic image segmentation.
Constructors
- SegmentationApi()
-
Bind the namespace. Reach it through
RunAnywhere.segmentation.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
segment(
ImageInput image, {SegmentationOptions? options}) → Future< SegmentationResult> -
Assign a class to every pixel of
image. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited