clear method
Drop every document from the corpus, keeping the session open.
Throws SDKException when the session is closed.
Implementation
Future<void> clear() async {
_requireLive();
DartBridgeRAG.shared.clearDocuments();
}
Drop every document from the corpus, keeping the session open.
Throws SDKException when the session is closed.
Future<void> clear() async {
_requireLive();
DartBridgeRAG.shared.clearDocuments();
}