DownloadExtracting class final

The transfer finished and the archive is being unpacked.

Inheritance

Constructors

DownloadExtracting(String operationId, {int sequence = 0, double? percent})
Announce the extraction phase.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
operationId String
Correlation id for this download.
final
percent double?
Extraction completion, when the backend reports incremental progress.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence int
Monotonic per-operation event counter.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited