GenerationReasoningDelta class final

One reasoning/thinking delta, emitted only when reasoning output is enabled.

Inheritance

Constructors

GenerationReasoningDelta(String text, {String requestId = ''})
Carry the reasoning text produced since the previous delta.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
requestId String
Correlation id for the generation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
Reasoning text produced since the previous delta.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited