GenerationStarted class final

The request was admitted and generation began.

Inheritance

Constructors

GenerationStarted(String requestId)
Announce a request id for correlation.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
requestId String
Correlation id for the generation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited