GenerationUsage class final

Token accounting for the request so far.

Inheritance

Constructors

GenerationUsage({required int inputTokens, required int outputTokens, String requestId = ''})
Carry running token counts.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
inputTokens int
Prompt tokens consumed.
final
outputTokens int
Completion tokens produced so far.
final
requestId String
Correlation id for the generation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited