ImageProgress class final

One denoising step completed.

Inheritance

Constructors

ImageProgress({required int step, required int totalSteps, Uint8List? partialImage})
Carry step counters and an optional preview.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
partialImage Uint8List?
Preview image, when partial reporting is enabled.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
step int
Steps completed.
final
totalSteps int
Steps in the schedule.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited