RagCompleted class final

The query finished; carries the grounded answer.

Inheritance

Constructors

RagCompleted(RagResult result)
Carry the terminal result.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
result RagResult
Answer, sources, and metrics.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited