RagRetrieved class final

Retrieval finished and produced these chunks.

Inheritance

Constructors

RagRetrieved(List<Match> matches)
Carry the retrieved chunks.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
matches List<Match>
Chunks that will ground the answer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited