RagToken class final

One decoded answer token.

Inheritance

Constructors

RagToken(String text, {TokenKind kind = TokenKind.text})
Carry a token and its semantic category.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
kind TokenKind
Whether this is answer text or a thought.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
Token text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited