SdkModelLoaded class final

A model finished loading.

Inheritance

Constructors

SdkModelLoaded(String id, ModelCategory category)
Carry the loaded model's identity.
const

Properties

category ModelCategory
Category the model was loaded under.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Model id.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited