VoiceAgentStateChanged class final
The agent moved between listening, thinking, and speaking.
- Inheritance
-
- Object
- VoiceEvent
- VoiceAgentStateChanged
Constructors
- VoiceAgentStateChanged(AgentState state)
-
Carry the new state.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → AgentState
-
What the agent is doing now.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited