AudioEncoding enum
Sample encoding of the bytes carried by an AudioInput.
Values
- pcm16 → const AudioEncoding
-
Signed 16-bit little-endian PCM.
- float32 → const AudioEncoding
-
32-bit little-endian float PCM.
- container → const AudioEncoding
-
Container-framed audio (WAV, MP3, FLAC, …) detected from the bytes.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AudioEncoding> - A constant List of the values in this enum, in order of their declaration.