ModelRef class

Reference to a registered model, plus an optional voice for TTS.

Constructors

ModelRef(String id, {String? voice})
Point at a model by registry id.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Registry model id.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
voice String?
Voice id inside a multi-voice TTS model. Never a model id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited