BackendPreference class

One ranked backend choice for LoadOptions.backendPreferences.

Constructors

BackendPreference(InferenceFramework backend, {bool required = false})
Build a backend preference.
const

Properties

backend InferenceFramework
Engine this preference names.
final
hashCode int
The hash code for this object.
no setterinherited
required bool
True fails the load instead of falling back past this entry.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited