DiarizationOptions class

Clustering controls for diarization.

Constructors

DiarizationOptions({double? threshold, int? minimumDurationMs, int? mergeGapMs})
Override any subset of the diarization defaults.

Properties

hashCode int
The hash code for this object.
no setterinherited
mergeGapMs int?
Adjacent same-speaker segments closer than this are merged.
final
minimumDurationMs int?
Segments shorter than this are dropped.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threshold double?
Speaker-change sensitivity. Null uses the model default.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toProto(AudioInput audio) DiarizationOptions
Build the generated diarization options for audio.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited