EmbedOptions class

Normalization and pooling controls for embeddings.

Constructors

EmbedOptions({bool? normalize, EmbeddingsPoolingStrategy? pooling})
Override any subset of the embedding defaults.

Properties

hashCode int
The hash code for this object.
no setterinherited
normalize bool
True L2-normalizes each vector after pooling.
no setter
pooling EmbeddingsPoolingStrategy
How token vectors collapse into one sentence vector.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toProto() EmbeddingsOptions
Build the generated embeddings options.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited