RagQueryOptions class

Per-query knobs for RagSession.query/queryStream.

Constructors

RagQueryOptions({RagRetrievalOptions? retrieval, LlmOptions? generation})
Override retrieval and/or generation for one query.
const

Properties

generation LlmOptions?
Generation knobs for this query's answer.
final
hashCode int
The hash code for this object.
no setterinherited
retrieval RagRetrievalOptions?
Retrieval overrides for this query.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited