RagRetrievalOptions class

Per-query retrieval overrides for RagSession.query/queryStream.

Constructors

RagRetrievalOptions({int? topK, double? similarityThreshold})
Override the session's retrieval defaults for one query.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
similarityThreshold double?
Minimum similarity a chunk needs to be returned this query.
final
topK int?
Chunks retrieved for this query. Null uses the session default.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited