AppliedAdapter class

One LoRA adapter currently applied to the loaded model.

Constructors

AppliedAdapter({required String id, required double scale})
Build an applied-adapter entry.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Adapter id.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double
Blend weight.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited