Audio class

Synthesized audio buffer.

Constructors

Audio({required Uint8List data, required int sampleRate, required AudioFormat format, required int durationMs})
Build a synthesized audio buffer.
const
Audio.fromProto(TTSOutput proto)
Build from the generated TTS output.
factory

Properties

data Uint8List
Raw audio bytes.
final
durationMs int
Playback length.
final
format AudioFormat
Encoding of data.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int
Samples per second.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited