DiarizationResult class

Who spoke when.

Constructors

DiarizationResult({required List<SpeakerSegment> segments, required int speakerCount})
Build a diarization result.
const
DiarizationResult.fromProto(DiarizationResult proto)
Build from the generated diarization result.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments List<SpeakerSegment>
Speaker spans in chronological order.
final
speakerCount int
Distinct speakers found.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited