Embedding class

One embedding vector and its position in the input list.

Constructors

Embedding({required int index, required Float32List vector})
Build an embedding.
const
Embedding.fromProto(EmbeddingVector proto)
Build from the generated embedding vector.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
Position of the source text in the request.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vector Float32List
Embedding components.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited