FinishReason enum
Why a generation stopped.
Values
- unspecified → const FinishReason
-
Commons sent no terminal reason (
FINISH_REASON_UNSPECIFIED). - stop → const FinishReason
-
The model emitted a stop token or stop sequence.
- length → const FinishReason
-
The output-token budget ran out.
- toolCalls → const FinishReason
-
The model asked to call one or more tools.
- cancelled → const FinishReason
-
The caller cancelled the request.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FinishReason> - A constant List of the values in this enum, in order of their declaration.