ImageData class

One generated image.

Constructors

ImageData({required Uint8List bytes, required int width, required int height, String? mediaType})
Build an image payload.
const

Properties

bytes Uint8List
Encoded image bytes.
final
hashCode int
The hash code for this object.
no setterinherited
height int
Pixel height.
final
mediaType String?
MIME type of bytes, when the backend reported one.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
Pixel width.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited