Match class

One retrieved chunk and its similarity to the query.

Constructors

Match({required String text, required double score, Map<String, String> metadata = const <String, String>{}})
Build a retrieval match.
const
Match.fromProto(RAGSearchResult proto)
Build from the generated search result.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, String>
Metadata carried by the source document.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score double
Similarity to the query.
final
text String
Chunk text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited