ModelsState class

What is loaded and how much storage the SDK is using.

Constructors

ModelsState({required Map<ModelCategory, ModelInfo> loaded, required int storageUsedBytes, required int storageFreeBytes})
Build a models-state snapshot.
const
ModelsState.fromProto(Map<ModelCategory, ModelInfo> loaded, StorageInfo storage)
Build from the loaded-model map and the generated storage info.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
loaded Map<ModelCategory, ModelInfo>
Loaded model per category.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageFreeBytes int
Bytes still free on the device.
final
storageUsedBytes int
Bytes the SDK's own storage occupies.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited