RagCapabilities class

RAG-session support of the currently registered backends.

Constructors

RagCapabilities({bool multiSession = true, bool persistent = false})
Build a RAG-capability snapshot.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
multiSession bool
More than one concurrent session is supported.
final
persistent bool
Sessions can persist their index to disk.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited