RankedResult class

One reranked document pointer.

Constructors

RankedResult({required int index, required double relevanceScore})
Build a ranked pointer.
const
RankedResult.fromProto(RerankScoredItem proto)
Build from the generated scored item.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
Position of the document in the request list.
final
relevanceScore double
Relevance score. Comparable only within one result set.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited