Segment class

A span of audio, in milliseconds from the start of the buffer.

Constructors

Segment({required int startMs, required int endMs})
Build a time span.
const

Properties

endMs int
Span end.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startMs int
Span start.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited