SegmentationResult class

Per-pixel class assignment for one image.

Constructors

SegmentationResult({required Uint16List classMask, required int width, required int height, required List<ClassInfo> classes, Uint8List? diagnosticImage})
Build a segmentation result.
const
SegmentationResult.fromProto(SegmentationResult proto)
Build from the generated segmentation result.
factory

Properties

classes List<ClassInfo>
Classes present in the mask.
final
classMask Uint16List
One class id per pixel, row-major at source dimensions.
final
diagnosticImage Uint8List?
Class-colour RGBA overlay, when requested.
final
hashCode int
The hash code for this object.
no setterinherited
height int
Mask height.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
Mask width.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited