StreamingCapabilities class

Per-modality streaming support, keyed by namespace name.

Constructors

StreamingCapabilities({bool llm = true, bool vlm = true, bool stt = true, bool tts = true, bool vad = true, bool rag = true, bool images = true})
Build a streaming-support snapshot.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
images bool
images.generateStream support.
final
llm bool
llm.generateStream support.
final
rag bool
RagSession.queryStream support.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stt bool
stt.openStream support.
final
tts bool
tts.synthesizeStream support.
final
vad bool
vad.openStream support.
final
vlm bool
vlm.generateStream support.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited