SttState class

Readiness of the speech-to-text component.

Constructors

SttState({required bool isReady, String? modelId, bool supportsStreaming = false, List<String> languages = const <String>[]})
Build an STT state snapshot.
const
SttState.fromProto(STTServiceState proto)
Build from the generated STT service state.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isReady bool
True when a model is loaded and can transcribe.
final
languages List<String>
BCP-47 tags the model recognizes.
final
modelId String?
Loaded model id.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportsStreaming bool
True when the model supports incremental transcription.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited