UnavailableCapability class

Whether a modality/backend/feature is honestly available right now.

Constructors

UnavailableCapability({required String name, required String reason})
Build an unavailable-capability entry.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Namespace or feature name.
final
reason String
Why it is unavailable right now.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited