Voice class

One synthesis voice offered by the loaded model.

Constructors

Voice({required String id, required String name, required String language})
Build a voice descriptor.
const
Voice.fromProto(TTSVoiceInfo proto)
Build from the generated voice info.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Voice id to pass as TtsOptions.voice.
final
language String
BCP-47 tag the voice speaks.
final
name String
Human-readable voice name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited