Generated-proto ToolValue helpers. Recursive JSON conversion lives in commons; this class only exposes ergonomic Dart entrypoints.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
array(
Iterable< ToolValue> values) → ToolValue -
boolean(
bool value) → ToolValue -
fromJSONString(
String json) → ToolValue -
intValue(
int value) → ToolValue -
jsonStringFromObject(
Map< String, ToolValue> object) → String -
nullValue(
) → ToolValue -
number(
num value) → ToolValue -
object(
Map< String, ToolValue> fields) → ToolValue -
parseObjectJSON(
String json) → Map< String, ToolValue> -
string(
String value) → ToolValue -
toJSONString(
ToolValue value) → String