metadataJSON property
Optional JSON metadata associated with the chunk. Empty strings from the bridge are converted to null.
Implementation
final String? metadataJSON;
Optional JSON metadata associated with the chunk. Empty strings from the bridge are converted to null.
final String? metadataJSON;