VADResult class

Result of Voice Activity Detection

Constructors

VADResult({required bool isSpeech, required double confidence, double startTime = 0, double endTime = 0})
const

Properties

confidence double
final
endTime double
final
hashCode int
The hash code for this object.
no setterinherited
isSpeech bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited