features/llm/structured_output/structured_output library

Structured output feature barrel export Matches iOS StructuredOutput module structure

Classes

Generatable
Protocol for types that can be generated as structured output from LLMs Matches iOS Generatable from Features/LLM/StructuredOutput/Generatable.swift
GenerationHints
Hints for structured output generation Matches iOS GenerationHints from Features/LLM/StructuredOutput/GenerationHints.swift
StreamAccumulator
Accumulates tokens from a stream into a complete response Matches iOS StreamAccumulator from Features/LLM/StructuredOutput/StreamAccumulator.swift
StreamToken
Token from structured output stream Matches iOS StreamToken from Features/LLM/StructuredOutput/StreamToken.swift
StructuredOutputHandler
Handles structured output generation and validation Matches iOS StructuredOutputHandler from Features/LLM/StructuredOutput/StructuredOutputHandler.swift