StructuredOutputConfig class

Configuration for structured output generation Mirrors Swift's StructuredOutputConfig

Constructors

StructuredOutputConfig({required String typeName, required String schema, bool includeSchemaInPrompt = true, String? name, bool strict = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
includeSchemaInPrompt bool
Whether to include schema instructions in the prompt
final
name String?
Name for the structured output (optional)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schema String
JSON schema describing the expected output
final
strict bool
Whether to enforce strict schema validation
final
typeName String
The type name being generated
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited