StructuredOutputResult<T> class

Result for structured output generation with parsed result and metrics

Constructors

StructuredOutputResult({required T result, required String rawText, required int inputTokens, required int tokensUsed, required double latencyMs, required double tokensPerSecond})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
inputTokens int
Generation metrics
final
latencyMs double
final
rawText String
Raw text from generation
final
result → T
The parsed structured output object
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokensPerSecond double
final
tokensUsed int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited