ToolCallFormatName class abstract
Constants for tool call format names.
The format logic is handled in C++ commons (single source of truth). Mirrors Swift SDK's ToolCallFormatName enum.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultFormat → const String
-
JSON format:
<tool_call>{"tool":"name","arguments":{...}}</tool_call>Use for most general-purpose models (Llama, Qwen, Mistral, etc.) - lfm2 → const String
-
Liquid AI format:
<|tool_call_start|>[func(args)]<|tool_call_end|>Use for LFM2-Tool models