autoExecute property
Whether to automatically execute tools or return them for manual execution (default: true)
Implementation
final bool autoExecute;
Whether to automatically execute tools or return them for manual execution (default: true)
final bool autoExecute;