replaceSystemPrompt property
If true, replaces the system prompt entirely instead of appending tool instructions
Implementation
final bool replaceSystemPrompt;
If true, replaces the system prompt entirely instead of appending tool instructions
final bool replaceSystemPrompt;