ToolCallingResult class

Result of a generation that may include tool calls

Constructors

ToolCallingResult({required String text, required List<ToolCall> toolCalls, required List<ToolResult> toolResults, required bool isComplete, String? conversationId})
const

Properties

conversationId String?
Conversation ID for continuing with tool results
final
hashCode int
The hash code for this object.
no setterinherited
isComplete bool
Whether the response is complete or waiting for tool results
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The final text response
final
toolCalls List<ToolCall>
Any tool calls the LLM made
final
toolResults List<ToolResult>
Results of executed tools (if autoExecute was true)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited