ToolDefinition class

Definition of a tool that the LLM can use

Constructors

ToolDefinition({required String name, required String description, required List<ToolParameter> parameters, String? category})
const

Properties

category String?
Category for organizing tools (optional)
final
description String
Human-readable description of what the tool does
final
hashCode int
The hash code for this object.
no setterinherited
name String
Unique name of the tool (e.g., "get_weather")
final
parameters List<ToolParameter>
Parameters the tool accepts
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited