ToolParameterType enum

Supported parameter types for tool arguments

Inheritance
Available extensions

Values

string → const ToolParameterType
const ToolParameterType('string')
number → const ToolParameterType
const ToolParameterType('number')
boolean → const ToolParameterType
const ToolParameterType('boolean')
object → const ToolParameterType
const ToolParameterType('object')
array → const ToolParameterType
const ToolParameterType('array')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String value) ToolParameterType

Constants

values → const List<ToolParameterType>
A constant List of the values in this enum, in order of their declaration.