ToolResult class

Result of executing a tool

Constructors

ToolResult({required String toolName, required bool success, Map<String, ToolValue>? result, String? error, String? callId})
const

Properties

callId String?
The original call ID (for tracking)
final
error String?
Error message (if failed)
final
hashCode int
The hash code for this object.
no setterinherited
result Map<String, ToolValue>?
Result data (if successful)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
Whether execution was successful
final
toolName String
Name of the tool that was executed
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited