ToolValue class sealed
A type-safe representation of JSON values for tool arguments and results.
Avoids using dynamic while supporting all JSON types.
Properties
-
arrayValue
→ List<
ToolValue> ? -
no setter
- boolValue → bool?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- intValue → int?
-
no setter
- isNull → bool
-
no setter
- numberValue → double?
-
no setter
-
objectValue
→ Map<
String, ToolValue> ? -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringValue → String?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → dynamic - Convert to JSON-compatible dynamic value
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited