VLMErrorCode enum

VLM-specific error codes Matches iOS SDKError.VLMErrorCode exactly

Inheritance
Available extensions

Values

notInitialized → const VLMErrorCode

VLM model not loaded

const VLMErrorCode(1)
modelLoadFailed → const VLMErrorCode

Model load operation failed

const VLMErrorCode(2)
processingFailed → const VLMErrorCode

Image processing failed

const VLMErrorCode(3)
invalidImage → const VLMErrorCode

Invalid image input

const VLMErrorCode(4)
cancelled → const VLMErrorCode

Generation was cancelled

const VLMErrorCode(5)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
rawValue int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<VLMErrorCode>
A constant List of the values in this enum, in order of their declaration.