VLMResult class

Result from VLM generation Matches iOS VLMResult

Constructors

VLMResult({required String text, required int promptTokens, required int completionTokens, required double totalTimeMs, required double tokensPerSecond})
const

Properties

completionTokens int
Number of tokens generated in the response
final
hashCode int
The hash code for this object.
no setterinherited
promptTokens int
Number of tokens in the prompt (including image tokens)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
Generated text describing the image
final
tokensPerSecond double
Tokens generated per second
final
totalTimeMs double
Total processing time in milliseconds
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited