VLMStreamingResult class

Streaming result for VLM generation Matches iOS VLMStreamingResult, adapted for Dart async patterns

Constructors

VLMStreamingResult({required Stream<String> stream, required Future<VLMResult> metrics, required void cancel()})
const

Properties

cancel → void Function()
Function to cancel the ongoing generation
final
hashCode int
The hash code for this object.
no setterinherited
metrics Future<VLMResult>
Future that completes with final result metrics when streaming finishes
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<String>
Stream of tokens as they are generated
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited