RacStorageCallbacks class base
Matches rac_storage_callbacks_t.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
calculateDirSize
↔ Pointer<
NativeFunction< RacStorageCalculateDirSizeNative> > -
getter/setter pair
-
deletePath
↔ Pointer<
NativeFunction< RacStorageDeletePathNative> > -
getter/setter pair
-
getAvailableSpace
↔ Pointer<
NativeFunction< RacStorageGetSpaceNative> > -
getter/setter pair
-
getFileSize
↔ Pointer<
NativeFunction< RacStorageCalculateDirSizeNative> > -
getter/setter pair
-
getTotalSpace
↔ Pointer<
NativeFunction< RacStorageGetSpaceNative> > -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
isModelLoaded
↔ Pointer<
NativeFunction< RacStorageIsModelLoadedNative> > -
getter/setter pair
-
pathExists
↔ Pointer<
NativeFunction< RacStorageIsModelLoadedNative> > -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
unloadModel
↔ Pointer<
NativeFunction< RacStorageUnloadModelNative> > -
getter/setter pair
-
userData
↔ Pointer<
Void> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited