HTTPServiceConfig class
HTTP Service Configuration
Matches React Native HTTPServiceConfig interface.
Constructors
- HTTPServiceConfig({required String baseURL, required String apiKey, SDKEnvironment environment = SDKEnvironment.production, int timeoutMs = defaultTimeoutMs})
-
const
Properties
- apiKey → String
-
API key for authentication
final
- baseURL → String
-
Base URL for API requests
final
- environment → SDKEnvironment
-
SDK environment
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeoutMs → int
-
Request timeout in milliseconds
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultTimeoutMs → const int
- Default timeout in milliseconds