VADConfiguration class
Configuration for VAD component
- Implemented types
Constructors
Properties
- calibrationMultiplier → double
-
Calibration multiplier (threshold = ambient noise * multiplier)
final
- enableAutoCalibration → bool
-
Enable automatic calibration
final
- energyThreshold → double
-
Energy threshold for voice detection (0.0 to 1.0)
final
- frameLength → double
-
Frame length in seconds
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleRate → int
-
Sample rate in Hz
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → void -
Validate the configuration
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited