DeviceInfo class

Available extensions

Constructors

DeviceInfo({String? deviceModel, String? deviceName, String? platform, String? osVersion, String? formFactor, String? architecture, String? chipName, Int64? totalMemory, Int64? availableMemory, bool? hasNeuralEngine, int? neuralEngineCores, String? gpuFamily, double? batteryLevel, String? batteryState, bool? isLowPowerMode, int? coreCount, int? performanceCores, int? efficiencyCores, String? deviceFingerprint, Iterable<MapEntry<String, String>>? platformExtras})
factory
DeviceInfo.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
DeviceInfo.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

architecture String
getter/setter pair
availableMemory ↔ Int64
getter/setter pair
batteryLevel double
getter/setter pair
batteryState String
getter/setter pair
chipName String
getter/setter pair
coreCount int
getter/setter pair
deviceFingerprint String
getter/setter pair
deviceModel String
getter/setter pair
deviceName String
getter/setter pair
efficiencyCores int
getter/setter pair
formFactor String
getter/setter pair
gpuFamily String
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
hasNeuralEngine bool
getter/setter pair
info_ → BuilderInfo
no setter
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
isLowPowerMode bool
getter/setter pair
neuralEngineCores int
getter/setter pair
osVersion String
getter/setter pair
performanceCores int
getter/setter pair
platform String
getter/setter pair
platformExtras → PbMap<String, String>
Platform-specific fields that are not part of the cross-SDK core (e.g. web: "has_webgpu", "has_shared_array_buffer"; android: "manufacturer", "android_api_level", "os_build_id", ...).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalMemory ↔ Int64
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearArchitecture() → void
clearAvailableMemory() → void
clearBatteryLevel() → void
clearBatteryState() → void
clearChipName() → void
clearCoreCount() → void
clearDeviceFingerprint() → void
clearDeviceModel() → void
clearDeviceName() → void
clearEfficiencyCores() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFormFactor() → void
clearGpuFamily() → void
clearHasNeuralEngine() → void
clearIsLowPowerMode() → void
clearNeuralEngineCores() → void
clearOsVersion() → void
clearPerformanceCores() → void
clearPlatform() → void
clearTotalMemory() → void
clone() DeviceInfo
Creates a deep copy of the fields in this message.
copyWith(void updates(DeviceInfo)) DeviceInfo
Apply updates to a copy of this message.
createEmptyInstance() DeviceInfo
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasArchitecture() bool
hasAvailableMemory() bool
hasBatteryLevel() bool
hasBatteryState() bool
hasChipName() bool
hasCoreCount() bool
hasDeviceFingerprint() bool
hasDeviceModel() bool
hasDeviceName() bool
hasEfficiencyCores() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasFormFactor() bool
hasGpuFamily() bool
hasHasNeuralEngine() bool
hasIsLowPowerMode() bool
hasNeuralEngineCores() bool
hasOsVersion() bool
hasPerformanceCores() bool
hasPlatform() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasTotalMemory() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() DeviceInfo
getDefault() DeviceInfo