DiffusionScheduler class
Only values with a C carrier are listed. UNSPECIFIED = the model's configured scheduler, which is what every engine does.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → DiffusionScheduler?
Constants
- DIFFUSION_SCHEDULER_DDIM → const DiffusionScheduler
- DIFFUSION_SCHEDULER_DPMPP_2M → const DiffusionScheduler
- DIFFUSION_SCHEDULER_DPMPP_2M_KARRAS → const DiffusionScheduler
- DIFFUSION_SCHEDULER_DPMPP_2M_SDE → const DiffusionScheduler
- DIFFUSION_SCHEDULER_EULER → const DiffusionScheduler
- DIFFUSION_SCHEDULER_EULER_A → const DiffusionScheduler
- DIFFUSION_SCHEDULER_LMS → const DiffusionScheduler
- DIFFUSION_SCHEDULER_PNDM → const DiffusionScheduler
- DIFFUSION_SCHEDULER_UNSPECIFIED → const DiffusionScheduler
-
values
→ const List<
DiffusionScheduler>