DownloadApi class
Constructors
- DownloadApi(RpcClient _client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancel(
ClientContext? ctx, DownloadCancelRequest request) → Future< DownloadCancelResult> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
plan(
ClientContext? ctx, DownloadPlanRequest request) → Future< DownloadPlanResult> -
resume(
ClientContext? ctx, DownloadResumeRequest request) → Future< DownloadResumeResult> -
start(
ClientContext? ctx, DownloadStartRequest request) → Future< DownloadStartResult> -
subscribe(
ClientContext? ctx, DownloadSubscribeRequest request) → Future< DownloadProgress> - Server-streaming: emits a DownloadProgress message every time bytes_downloaded crosses a per-engine reporting threshold (currently every 64 KiB) until state ∈ {COMPLETED, FAILED, CANCELLED}.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited