LogLevel class
Severity, mirroring the C ABI rac_log_level_t. Larger value = more severe.
0 is TRACE (not UNSPECIFIED) to keep numeric parity with the C enum — the
same C-ABI-aligned convention used by HttpDownloadStatus (0=OK) and
SdkInitEnvironment (0=DEVELOPMENT).
- Available extensions
Properties
- displayName → String
-
Available on LogLevel, provided by the LogLevelDisplayName extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
- wireString → String
-
Available on LogLevel, provided by the LogLevelWireString extension
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- LOG_LEVEL_DEBUG → const LogLevel
- LOG_LEVEL_ERROR → const LogLevel
- LOG_LEVEL_FATAL → const LogLevel
- LOG_LEVEL_INFO → const LogLevel
- LOG_LEVEL_TRACE → const LogLevel
- LOG_LEVEL_WARNING → const LogLevel
-
values
→ const List<
LogLevel>