ArchiveStructure class
- Available extensions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
- wireString → String
-
Available on ArchiveStructure, provided by the ArchiveStructureWireString extension
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toC(
) → int -
Available on ArchiveStructure, provided by the ProtoArchiveStructureCppBridge extension
Convert a generated archive structure enum to C++ rac_archive_structure_t. Delegates to commons'rac_archive_structure_from_proto. Falls back toRAC_ARCHIVE_STRUCTURE_UNKNOWN(99) on UNSPECIFIED / unrecognized. -
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → ArchiveStructure?
Constants
- ARCHIVE_STRUCTURE_DIRECTORY_BASED → const ArchiveStructure
- ARCHIVE_STRUCTURE_NESTED_DIRECTORY → const ArchiveStructure
- ARCHIVE_STRUCTURE_SINGLE_FILE_NESTED → const ArchiveStructure
- ARCHIVE_STRUCTURE_UNKNOWN → const ArchiveStructure
- ARCHIVE_STRUCTURE_UNSPECIFIED → const ArchiveStructure
-
values
→ const List<
ArchiveStructure>