AudioFormat class
Audio format — union of all cases currently defined across SDKs. Sources pre-IDL: Kotlin AudioTypes.kt:12 (pcm, wav, mp3, opus, aac, flac, ogg, pcm_16bit) Kotlin ComponentTypes.kt:39 (pcm, wav, mp3, aac, ogg, opus, flac) ← duplicate Swift AudioTypes.swift:17 (pcm, wav, mp3, opus, aac, flac) Dart audio_format.dart:3 (wav, mp3, m4a, flac, pcm, opus) RN TTSTypes.ts:36 ('pcm' | 'wav' | 'mp3')
- Available extensions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
- wireString → String
-
Available on AudioFormat, provided by the AudioFormatWireString extension
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → AudioFormat?
Constants
- AUDIO_FORMAT_AAC → const AudioFormat
- AUDIO_FORMAT_FLAC → const AudioFormat
- AUDIO_FORMAT_M4A → const AudioFormat
- AUDIO_FORMAT_MP3 → const AudioFormat
- AUDIO_FORMAT_OGG → const AudioFormat
- AUDIO_FORMAT_OPUS → const AudioFormat
- AUDIO_FORMAT_PCM → const AudioFormat
- AUDIO_FORMAT_PCM_S16LE → const AudioFormat
- AUDIO_FORMAT_UNSPECIFIED → const AudioFormat
- AUDIO_FORMAT_WAV → const AudioFormat
-
values
→ const List<
AudioFormat>