ModelArtifactType class
What kind of bundle a model ships as.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → ModelArtifactType?
Constants
- MODEL_ARTIFACT_TYPE_ARCHIVE → const ModelArtifactType
- MODEL_ARTIFACT_TYPE_BUILT_IN → const ModelArtifactType
- MODEL_ARTIFACT_TYPE_CUSTOM → const ModelArtifactType
- MODEL_ARTIFACT_TYPE_DIRECTORY → const ModelArtifactType
- MODEL_ARTIFACT_TYPE_MULTI_FILE → const ModelArtifactType
- MODEL_ARTIFACT_TYPE_SINGLE_FILE → const ModelArtifactType
- MODEL_ARTIFACT_TYPE_TAR_BZ2_ARCHIVE → const ModelArtifactType
- MODEL_ARTIFACT_TYPE_TAR_GZ_ARCHIVE → const ModelArtifactType
- MODEL_ARTIFACT_TYPE_TAR_XZ_ARCHIVE → const ModelArtifactType
- MODEL_ARTIFACT_TYPE_UNSPECIFIED → const ModelArtifactType
- MODEL_ARTIFACT_TYPE_ZIP_ARCHIVE → const ModelArtifactType
-
values
→ const List<
ModelArtifactType>