ModelRegistryStatus class
Durable catalog state, not a live transfer stream. Byte counters and progress events live in download_service.proto.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → ModelRegistryStatus?
Constants
- MODEL_REGISTRY_STATUS_DOWNLOADED → const ModelRegistryStatus
- MODEL_REGISTRY_STATUS_DOWNLOADING → const ModelRegistryStatus
- MODEL_REGISTRY_STATUS_ERROR → const ModelRegistryStatus
- MODEL_REGISTRY_STATUS_LOADED → const ModelRegistryStatus
- MODEL_REGISTRY_STATUS_LOADING → const ModelRegistryStatus
- MODEL_REGISTRY_STATUS_REGISTERED → const ModelRegistryStatus
- MODEL_REGISTRY_STATUS_UNSPECIFIED → const ModelRegistryStatus
-
values
→ const List<
ModelRegistryStatus>