SDKEnvironment class


SDK environment. Sources pre-IDL: Swift SDKEnvironment.swift:5 (development, staging, production) Kotlin RunAnywhere.kt:47 (DEVELOPMENT, STAGING, PRODUCTION, cEnvironment) Kotlin SDKLogger.kt:159 (DEVELOPMENT, STAGING, PRODUCTION) ← duplicate Dart sdk_environment.dart:5 (development, staging, production) RN enums.ts:11 (Development, Staging, Production) Web enums.ts:9 (Development, Staging, Production)

Available extensions

Properties

defaultLogLevel LogLevel

Available on SDKEnvironment, provided by the SDKEnvironmentExtension extension

no setter
description String

Available on SDKEnvironment, provided by the SDKEnvironmentExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
isCompatibleWithCurrentBuild bool

Available on SDKEnvironment, provided by the SDKEnvironmentExtension extension

no setter
isProduction bool

Available on SDKEnvironment, provided by the SDKEnvironmentExtension extension

Check if this is a production environment (uses C++). Mirrors Swift isProduction (SDKEnvironment.swift:73).
no setter
isTesting bool

Available on SDKEnvironment, provided by the SDKEnvironmentExtension extension

Check if this is a testing environment (uses C++).
no setter
name String
This enum's name, as specified in the .proto file.
finalinherited
requiresAuthentication bool

Available on SDKEnvironment, provided by the SDKEnvironmentExtension extension

Requires API authentication (non-development) — uses C++.
no setter
requiresBackendURL bool

Available on SDKEnvironment, provided by the SDKEnvironmentExtension extension

Check if this environment requires a valid backend URL (uses C++).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldSendTelemetry bool

Available on SDKEnvironment, provided by the SDKEnvironmentExtension extension

Should send telemetry data (production only) — uses C++. Mirrors Swift shouldSendTelemetry (SDKEnvironment.swift:121).
no setter
shouldSyncWithBackend bool

Available on SDKEnvironment, provided by the SDKEnvironmentExtension extension

Should sync with backend (non-development) — uses C++.
no setter
value int
This enum's integer value, as specified in the .proto file.
finalinherited
wireString String

Available on SDKEnvironment, provided by the SDKEnvironmentWireString extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) SDKEnvironment?