chunkOverlap property
Overlap tokens between consecutive chunks. Must be < chunk_size. Optional so callers can explicitly request zero overlap (no overlap) without it being silently replaced by the canonical default of 64.
Implementation
@$pb.TagNumber(7)
$core.int get chunkOverlap => $_getIZ(6);
Implementation
@$pb.TagNumber(7)
set chunkOverlap($core.int value) => $_setSignedInt32(6, value);