SDKEvent_Event enum
Values
- initialization → const SDKEvent_Event
- configuration → const SDKEvent_Event
- generation → const SDKEvent_Event
- model → const SDKEvent_Event
- performance → const SDKEvent_Event
- network → const SDKEvent_Event
- storage → const SDKEvent_Event
- framework → const SDKEvent_Event
- device → const SDKEvent_Event
- componentInit → const SDKEvent_Event
- voice → const SDKEvent_Event
- voicePipeline → const SDKEvent_Event
- componentLifecycle → const SDKEvent_Event
- session → const SDKEvent_Event
- auth → const SDKEvent_Event
- modelRegistry → const SDKEvent_Event
- download → const SDKEvent_Event
- storageLifecycle → const SDKEvent_Event
- hardwareRouting → const SDKEvent_Event
- capability → const SDKEvent_Event
- telemetry → const SDKEvent_Event
- cancellation → const SDKEvent_Event
- failure → const SDKEvent_Event
- notSet → const SDKEvent_Event
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SDKEvent_Event> - A constant List of the values in this enum, in order of their declaration.