ModelEventKind class

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) ModelEventKind?

Constants

MODEL_EVENT_KIND_BUILT_IN_REGISTERED → const ModelEventKind
MODEL_EVENT_KIND_CATALOG_LOADED → const ModelEventKind
MODEL_EVENT_KIND_CUSTOM_MODEL_ADDED → const ModelEventKind
MODEL_EVENT_KIND_DELETE_COMPLETED → const ModelEventKind
MODEL_EVENT_KIND_DELETE_FAILED → const ModelEventKind
MODEL_EVENT_KIND_DELETE_STARTED → const ModelEventKind
MODEL_EVENT_KIND_DOWNLOAD_CANCELLED → const ModelEventKind
MODEL_EVENT_KIND_DOWNLOAD_COMPLETED → const ModelEventKind
MODEL_EVENT_KIND_DOWNLOAD_FAILED → const ModelEventKind
MODEL_EVENT_KIND_DOWNLOAD_PROGRESS → const ModelEventKind
MODEL_EVENT_KIND_DOWNLOAD_STARTED → const ModelEventKind
MODEL_EVENT_KIND_EXTRACTION_COMPLETED → const ModelEventKind
MODEL_EVENT_KIND_EXTRACTION_FAILED → const ModelEventKind
MODEL_EVENT_KIND_EXTRACTION_PROGRESS → const ModelEventKind
MODEL_EVENT_KIND_EXTRACTION_STARTED → const ModelEventKind
MODEL_EVENT_KIND_LIST_COMPLETED → const ModelEventKind
MODEL_EVENT_KIND_LIST_FAILED → const ModelEventKind
MODEL_EVENT_KIND_LIST_REQUESTED → const ModelEventKind
MODEL_EVENT_KIND_LOAD_COMPLETED → const ModelEventKind
MODEL_EVENT_KIND_LOAD_FAILED → const ModelEventKind
MODEL_EVENT_KIND_LOAD_PROGRESS → const ModelEventKind
MODEL_EVENT_KIND_LOAD_STARTED → const ModelEventKind
MODEL_EVENT_KIND_UNLOAD_COMPLETED → const ModelEventKind
MODEL_EVENT_KIND_UNLOAD_FAILED → const ModelEventKind
MODEL_EVENT_KIND_UNLOAD_STARTED → const ModelEventKind
MODEL_EVENT_KIND_UNSPECIFIED → const ModelEventKind
values → const List<ModelEventKind>