VoiceEvent_Payload enum
Values
- userSaid → const VoiceEvent_Payload
- assistantToken → const VoiceEvent_Payload
- audio → const VoiceEvent_Payload
- vad → const VoiceEvent_Payload
- interrupted → const VoiceEvent_Payload
- state → const VoiceEvent_Payload
- error → const VoiceEvent_Payload
- metrics → const VoiceEvent_Payload
- componentStateChanged → const VoiceEvent_Payload
- sessionError → const VoiceEvent_Payload
- sessionStarted → const VoiceEvent_Payload
- sessionStopped → const VoiceEvent_Payload
- agentResponseStarted → const VoiceEvent_Payload
- agentResponseCompleted → const VoiceEvent_Payload
- speechTurnDetection → const VoiceEvent_Payload
- turnLifecycle → const VoiceEvent_Payload
- wakewordDetected → const VoiceEvent_Payload
- audioLevel → const VoiceEvent_Payload
- componentProgress → const VoiceEvent_Payload
- notSet → const VoiceEvent_Payload
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VoiceEvent_Payload> - A constant List of the values in this enum, in order of their declaration.