DartBridgeDevConfig class
Development configuration bridge
Wraps C++ rac_dev_config.h functions for development mode with Supabase backend. Credentials are stored ONLY in C++ development_config.cpp (git-ignored).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- buildToken → String?
-
Get build token for development mode
Returns null if not configured
no setter
- isAvailable → bool
-
Check if development config is available
no setter
- sentryDSN → String?
-
Get Sentry DSN for crash reporting (optional)
Returns null if not configured
no setter
- supabaseKey → String?
-
Get Supabase anon key for development mode
Returns null if not configured
no setter
- supabaseURL → String?
-
Get Supabase URL for development mode
Returns null if not configured
no setter