DartBridgeEvents class
Events bridge for C++ event routing.
Matches Swift's CppBridge+Events.swift.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
emit(
SDKEvent event) → void - Emit an event to subscribers
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
subscribe(
void onEvent(SDKEvent event), {String? eventType}) → StreamSubscription< SDKEvent> - Subscribe to events of a specific type
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
eventStream
→ Stream<
SDKEvent> -
Stream of SDK events from C++
no setter
- instance → DartBridgeEvents
-
final
Static Methods
-
register(
) → void - Register events callback with C++
-
unregister(
) → void - Unregister events callback