NativeStorageAvailability class

Storage availability result from C++ rac_file_manager_check_storage.

Constructors

NativeStorageAvailability({required bool isAvailable, required int requiredSpace, required int availableSpace, required bool hasWarning, String? recommendation})
const

Properties

availableSpace int
final
hashCode int
The hash code for this object.
no setterinherited
hasWarning bool
final
isAvailable bool
final
recommendation String?
final
requiredSpace int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited