NativeStorageInfo class
Combined storage information from C++ file manager.
Constructors
Properties
- cacheSize → int
-
final
- deviceFree → int
-
final
- deviceTotal → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- modelsSize → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tempSize → int
-
final
- totalAppSize → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited