DartBridgeStructuredOutput class
Thin C ABI bridge for structured-output parse / generate / prepare-prompt.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generate(
StructuredOutputRequest request) → StructuredOutputResult - Run full structured-output generation against the lifecycle-owned LLM via commons. Commons handles prompt preparation, LLM generation, thinking-tag stripping, JSON extraction, and schema validation.
-
makeGenerateRequest(
{required String prompt, required StructuredOutputOptions options, String requestId = ''}) → StructuredOutputRequest -
Build a
StructuredOutputRequestfor the given prompt + options. -
makeParseRequest(
{required String text, required JSONSchema schema, String requestId = ''}) → StructuredOutputParseRequest -
Build a
StructuredOutputParseRequestfor the given text + schema. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
StructuredOutputParseRequest request) → StructuredOutputResult - Parse structured output from raw model text via commons.
-
preparePrompt(
{required String prompt, required StructuredOutputOptions options, String requestId = ''}) → StructuredOutputPromptResult - Build the schema-instrumented prompt for structured output via commons.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
final