RacRagQueryStruct class base
RAG query parameters struct matching rac_rag_query_t
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- maxTokens ↔ int
-
Max tokens to generate (default 512)
getter/setter pair
-
question
↔ Pointer<
Utf8> -
User question
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
systemPrompt
↔ Pointer<
Utf8> -
Optional system prompt override
getter/setter pair
- temperature ↔ double
-
Sampling temperature (default 0.7)
getter/setter pair
- topK ↔ int
-
Top-k sampling (default 40)
getter/setter pair
- topP ↔ double
-
Nucleus sampling (default 0.9)
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited