RacRagResultStruct class base
RAG result with answer and context matching rac_rag_result_t
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
answer
↔ Pointer<
Utf8> -
Generated answer (caller must free via rac_rag_result_free)
getter/setter pair
-
contextUsed
↔ Pointer<
Utf8> -
Full context sent to LLM (caller must free via rac_rag_result_free)
getter/setter pair
- generationTimeMs ↔ double
-
Time for LLM generation (ms)
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- numChunks ↔ int
-
Number of chunks retrieved
getter/setter pair
- retrievalTimeMs ↔ double
-
Time for retrieval phase (ms)
getter/setter pair
-
retrievedChunks
↔ Pointer<
RacSearchResultStruct> -
Retrieved chunks (caller must free via rac_rag_result_free)
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalTimeMs ↔ double
-
Total query time (ms)
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited