EmbeddingsApi class
Text embedding.
Constructors
- EmbeddingsApi()
-
Bind the namespace. Reach it through
RunAnywhere.embeddings.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
embed(
List< String> texts, {String? model, EmbedOptions? options}) → Future<List< Embedding> > -
Embed
texts, returning one vector per input in input order. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited