RagApi class
Retrieval-augmented generation sessions.
Constructors
- RagApi()
-
Bind the namespace. Reach it through
RunAnywhere.rag.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
open(
{required ModelRef embeddingModel, ModelRef? llmModel, RagConfig? config}) → Future< RagSession> -
Open a session over
embeddingModel, optionally generating withllmModel. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited