VlmApi class
Vision-language generation over one image.
Constructors
- VlmApi()
-
Bind the namespace. Reach it through
RunAnywhere.vlm.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancel(
) → void - Cancel the in-flight vision generation, if any.
-
generate(
ImageInput image, String prompt, {LlmOptions? options}) → Future< GenerationResult> -
Answer
promptaboutimage. -
generateStream(
ImageInput image, String prompt, {LlmOptions? options}) → Stream< GenerationEvent> -
Stream an answer to
promptaboutimagetoken by token. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited