VoiceApi class
Speech-to-speech agent sessions.
Constructors
- VoiceApi()
-
Bind the namespace. Reach it through
RunAnywhere.voice.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createSession(
{required ModelRef stt, required ModelRef llm, required ModelRef tts, VadOptions? vad, TurnHandlingOptions? turnHandling, LlmOptions? generation, bool downloadIfNeeded = true}) → Future< VoiceSession> -
Build a session over
stt,llm, andtts, downloading what is absent. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited