DownloadFailed class final
The transfer failed in flight. Terminal — no event follows.
- Inheritance
-
- Object
- DownloadEvent
- DownloadFailed
Constructors
- DownloadFailed(String operationId, SDKException error, {int sequence = 0})
-
Carry the failure.
const
Properties
- error → SDKException
-
What went wrong.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- operationId → String
-
Correlation id for this download.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequence → int
-
Monotonic per-operation event counter.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited