ImageCompleted class final
Sampling finished; carries the images.
- Inheritance
-
- Object
- ImageEvent
- ImageCompleted
Constructors
- ImageCompleted(ImageResult result)
-
Carry the terminal result.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- result → ImageResult
-
Generated images and the sampling parameters used.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited