SegmentationOptions class
Diagnostic controls for segmentation.
Constructors
- SegmentationOptions({bool includeDiagnosticImage = false})
-
Ask for the human-viewable class-colour overlay alongside the mask.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeDiagnosticImage → bool
-
True also returns a deterministic class-colour RGBA image.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toProto(
) → SegmentationOptions - Build the generated segmentation options.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited