TurnHandlingOptions class
Turn-taking behaviour of a voice session.
Constructors
- TurnHandlingOptions({Endpointing endpointing = const Endpointing(), Interruption interruption = const Interruption()})
-
Configure endpointing and barge-in.
const
Properties
- endpointing → Endpointing
-
When a user turn ends.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- interruption → Interruption
-
Whether the user may interrupt the agent.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited