AudioChunk class
One chunk of a streamed synthesis.
Constructors
- AudioChunk({required Uint8List data, required int index, required bool isFinal})
-
Build a synthesis chunk.
const
- AudioChunk.fromProto(TTSOutput proto)
-
Build from the generated TTS output.
factory
Properties
- data → Uint8List
-
Raw audio bytes for this chunk.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
Zero-based position in the chunk sequence.
final
- isFinal → bool
-
True on the last chunk.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited