ClassInfo class
One class present in a segmentation mask.
Constructors
Properties
- classId → int
-
Numeric class id used in the mask.
final
- fraction → double
-
Share of the image covered by this class.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
Human-readable class name.
final
- pixelCount → int
-
Pixels assigned to this class.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited