ImageResult class
Images produced by one generation, plus the sampling parameters used.
Constructors
-
ImageResult({required List<
ImageData> images, required int seed, required int steps}) -
Build an image-generation result.
const
- ImageResult.fromProto(DiffusionResult proto, {required int steps})
-
Build from the generated diffusion result.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
images
→ List<
ImageData> -
Generated images, in batch order.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seed → int
-
Seed the sampler actually used.
final
- steps → int
-
Denoising steps run.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited