StreamingCapabilities class
Per-modality streaming support, keyed by namespace name.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- images → bool
-
images.generateStreamsupport.final - llm → bool
-
llm.generateStreamsupport.final - rag → bool
-
RagSession.queryStreamsupport.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stt → bool
-
stt.openStreamsupport.final - tts → bool
-
tts.synthesizeStreamsupport.final - vad → bool
-
vad.openStreamsupport.final - vlm → bool
-
vlm.generateStreamsupport.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited