ToolCapabilities class
Tool-calling support of the currently registered backends.
Constructors
- ToolCapabilities({bool registry = true, bool parallel = false, bool cancellation = true})
-
Build a tool-capability snapshot.
const
Properties
- cancellation → bool
-
A tool call can be cancelled mid-flight.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- parallel → bool
-
Multiple tool calls can run concurrently.
final
- registry → bool
-
A tool registry is available.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited