ModelLifecycleResolvedArtifactPaths class

Primary and companion paths selected by commons model path resolution.

Constructors

ModelLifecycleResolvedArtifactPaths({required String primaryModelPath, String? visionProjectorPath, String? tokenizerPath, String? configPath, String? vocabularyPath, String? mergesPath, String? labelsPath})
const

Properties

configPath String?
final
hashCode int
The hash code for this object.
no setterinherited
labelsPath String?
final
mergesPath String?
final
primaryModelPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenizerPath String?
final
visionProjectorPath String?
final
vocabularyPath String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited