RunAnywherePluginLoaderCapability class
Plugin Loader capability surface (canonical 12 namespace).
Access via RunAnywhere.pluginLoader.
Properties
- apiVersion → int
-
Compile-time plugin API version this build was built against.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- registeredCount → int
-
Total number of plugins currently registered.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
listLoaded(
) → List< PluginInfo> - Snapshot of all currently-loaded plugins.
-
load(
String path) → Future< PluginInfo> -
Load a shared library at
pathand register therac_plugin_entry_<stem>it exposes with the in-process plugin registry. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registeredNames(
) → List< String> - Snapshot of currently-registered plugin names.
-
toString(
) → String -
A string representation of this object.
inherited
-
unload(
String name) → Future< void> -
Unregister a previously-loaded plugin and
dlcloseits handle.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
no setter