NumberToolValue class
Constructors
- NumberToolValue(double value)
-
const
Properties
-
arrayValue
→ List<
ToolValue> ? -
no setterinherited
- boolValue → bool?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- intValue → int?
-
no setterinherited
- isNull → bool
-
no setterinherited
- numberValue → double?
-
no setterinherited
-
objectValue
→ Map<
String, ToolValue> ? -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringValue → String?
-
no setterinherited
- value → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → dynamic -
Convert to JSON-compatible dynamic value
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited