ToolCall class
A request from the LLM to execute a tool
Constructors
Properties
-
arguments
→ Map<
String, ToolValue> -
Arguments to pass to the tool
final
- callId → String?
-
Unique ID for this tool call (for tracking)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolName → String
-
Name of the tool to execute
final
Methods
-
getBool(
String key) → bool? - Get a bool argument by name
-
getNumber(
String key) → double? - Get a number argument by name
-
getString(
String key) → String? - Get a string argument by name
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited