ToolCallingOptions class
Options for tool-enabled generation
Constructors
Properties
- autoExecute → bool
-
Whether to automatically execute tools or return them for manual execution (default: true)
final
- formatName → String
-
Tool calling format name (e.g., "default", "lfm2")
Different models are trained on different tool calling formats.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- keepToolsAvailable → bool
-
If true, keeps tool definitions available after the first tool call
final
- maxTokens → int?
-
Maximum tokens to generate
final
- maxToolCalls → int
-
Maximum number of tool calls allowed in one conversation turn (default: 5)
final
- replaceSystemPrompt → bool
-
If true, replaces the system prompt entirely instead of appending tool instructions
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- systemPrompt → String?
-
System prompt to use (will be merged with tool instructions by default)
final
- temperature → double?
-
Temperature for generation
final
-
tools
→ List<
ToolDefinition> ? -
Available tools for this generation (if not provided, uses registered tools)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited