ToolParameter class
A single parameter definition for a tool
Constructors
-
ToolParameter({required String name, required ToolParameterType type, required String description, bool required = true, List<
String> ? enumValues}) -
const
Properties
- description → String
-
Human-readable description
final
-
enumValues
→ List<
String> ? -
Allowed values (for enum-like parameters)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Parameter name
final
- required → bool
-
Whether this parameter is required
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ToolParameterType
-
Data type of the parameter
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited